.ag-theme-balham {
  -webkit-font-smoothing: antialiased;
  color: #000;
  color: var(--ag-foreground-color, #000);
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 12px;
  line-height: normal;
}
@font-face {
  font-family: "agGridBalham";
  src: url("data:application/font-woff;charset=utf-8;base64, ") format("woff");
  font-weight: normal;
  font-style: normal;
}
.ag-theme-balham .ag-icon {
  font-family: "agGridBalham";
  font-size: 16px;
  line-height: 16px;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.ag-theme-balham .ag-icon-aggregation::before {
  content: "\f101";
}
.ag-theme-balham .ag-icon-arrows::before {
  content: "\f102";
}
.ag-theme-balham .ag-icon-asc::before {
  content: "\f103";
}
.ag-theme-balham .ag-icon-cancel::before {
  content: "\f104";
}
.ag-theme-balham .ag-icon-chart::before {
  content: "\f105";
}
.ag-theme-balham .ag-icon-color-picker::before {
  content: "\f109";
}
.ag-theme-balham .ag-icon-columns::before {
  content: "\f10a";
}
.ag-theme-balham .ag-icon-contracted::before {
  content: "\f10b";
}
.ag-theme-balham .ag-icon-copy::before {
  content: "\f10c";
}
.ag-theme-balham .ag-icon-cross::before {
  content: "\f10d";
}
.ag-theme-balham .ag-icon-csv::before {
  content: "\f10e";
}
.ag-theme-balham .ag-icon-desc::before {
  content: "\f10f";
}
.ag-theme-balham .ag-icon-excel::before {
  content: "\f110";
}
.ag-theme-balham .ag-icon-expanded::before {
  content: "\f111";
}
.ag-theme-balham .ag-icon-eye-slash::before {
  content: "\f112";
}
.ag-theme-balham .ag-icon-eye::before {
  content: "\f113";
}
.ag-theme-balham .ag-icon-filter::before {
  content: "\f114";
}
.ag-theme-balham .ag-icon-first::before {
  content: "\f115";
}
.ag-theme-balham .ag-icon-grip::before {
  content: "\f116";
}
.ag-theme-balham .ag-icon-group::before {
  content: "\f117";
}
.ag-theme-balham .ag-icon-last::before {
  content: "\f118";
}
.ag-theme-balham .ag-icon-left::before {
  content: "\f119";
}
.ag-theme-balham .ag-icon-linked::before {
  content: "\f11a";
}
.ag-theme-balham .ag-icon-loading::before {
  content: "\f11b";
}
.ag-theme-balham .ag-icon-maximize::before {
  content: "\f11c";
}
.ag-theme-balham .ag-icon-menu::before {
  content: "\f11d";
}
.ag-theme-balham .ag-icon-minimize::before {
  content: "\f11e";
}
.ag-theme-balham .ag-icon-next::before {
  content: "\f11f";
}
.ag-theme-balham .ag-icon-none::before {
  content: "\f120";
}
.ag-theme-balham .ag-icon-not-allowed::before {
  content: "\f121";
}
.ag-theme-balham .ag-icon-paste::before {
  content: "\f122";
}
.ag-theme-balham .ag-icon-pin::before {
  content: "\f123";
}
.ag-theme-balham .ag-icon-pivot::before {
  content: "\f124";
}
.ag-theme-balham .ag-icon-previous::before {
  content: "\f125";
}
.ag-theme-balham .ag-icon-right::before {
  content: "\f128";
}
.ag-theme-balham .ag-icon-save::before {
  content: "\f129";
}
.ag-theme-balham .ag-icon-small-down::before {
  content: "\f12a";
}
.ag-theme-balham .ag-icon-small-left::before {
  content: "\f12b";
}
.ag-theme-balham .ag-icon-small-right::before {
  content: "\f12c";
}
.ag-theme-balham .ag-icon-small-up::before {
  content: "\f12d";
}
.ag-theme-balham .ag-icon-tick::before {
  content: "\f12e";
}
.ag-theme-balham .ag-icon-tree-closed::before {
  content: "\f12f";
}
.ag-theme-balham .ag-icon-tree-indeterminate::before {
  content: "\f130";
}
.ag-theme-balham .ag-icon-tree-open::before {
  content: "\f131";
}
.ag-theme-balham .ag-icon-unlinked::before {
  content: "\f132";
}
.ag-theme-balham .ag-icon-row-drag::before {
  content: "\f116";
}
.ag-theme-balham .ag-left-arrow::before {
  content: "\f119";
}
.ag-theme-balham .ag-right-arrow::before {
  content: "\f128";
}
.ag-theme-balham .ag-root-wrapper {
  background-color: white;
  background-color: var(--ag-background-color, white);
}
.ag-theme-balham [class^=ag-], .ag-theme-balham [class^=ag-]:focus, .ag-theme-balham [class^=ag-]:after, .ag-theme-balham [class^=ag-]:before {
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  outline: none;
}
.ag-theme-balham [class^=ag-]::-ms-clear {
  display: none;
}
.ag-theme-balham .ag-checkbox .ag-input-wrapper,
.ag-theme-balham .ag-radio-button .ag-input-wrapper {
  overflow: visible;
}
.ag-theme-balham .ag-range-field .ag-input-wrapper {
  height: 100%;
}
.ag-theme-balham .ag-toggle-button {
  -webkit-box-flex: 0;
          flex: none;
  width: unset;
  min-width: unset;
}
.ag-theme-balham .ag-ltr .ag-label-align-right .ag-label {
  margin-left: 4px;
}

.ag-theme-balham .ag-rtl .ag-label-align-right .ag-label {
  margin-right: 4px;
}

.ag-theme-balham input[class^=ag-] {
  margin: 0;
  background-color: white;
  background-color: var(--ag-background-color, white);
}
.ag-theme-balham textarea[class^=ag-],
.ag-theme-balham select[class^=ag-] {
  background-color: white;
  background-color: var(--ag-background-color, white);
}
.ag-theme-balham input[class^=ag-]:not([type]),
.ag-theme-balham input[class^=ag-][type=text],
.ag-theme-balham input[class^=ag-][type=number],
.ag-theme-balham input[class^=ag-][type=tel],
.ag-theme-balham input[class^=ag-][type=date],
.ag-theme-balham input[class^=ag-][type=datetime-local],
.ag-theme-balham textarea[class^=ag-] {
  font-size: inherit;
  line-height: inherit;
  color: inherit;
  border-width: 1px;
  border-style: solid;
  border-color: #95a5a6;
  border-color: var(--ag-input-border-color, #95a5a6);
}
.ag-theme-balham input[class^=ag-]:not([type]):disabled,
.ag-theme-balham input[class^=ag-][type=text]:disabled,
.ag-theme-balham input[class^=ag-][type=number]:disabled,
.ag-theme-balham input[class^=ag-][type=tel]:disabled,
.ag-theme-balham input[class^=ag-][type=date]:disabled,
.ag-theme-balham input[class^=ag-][type=datetime-local]:disabled,
.ag-theme-balham textarea[class^=ag-]:disabled {
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
  background-color: #ebebeb;
  background-color: var(--ag-input-disabled-background-color, #ebebeb);
  border-color: rgba(149, 165, 166, 0.3);
  border-color: var(--ag-input-disabled-border-color, rgba(149, 165, 166, 0.3));
}
.ag-theme-balham input[class^=ag-]:not([type]):focus,
.ag-theme-balham input[class^=ag-][type=text]:focus,
.ag-theme-balham input[class^=ag-][type=number]:focus,
.ag-theme-balham input[class^=ag-][type=tel]:focus,
.ag-theme-balham input[class^=ag-][type=date]:focus,
.ag-theme-balham input[class^=ag-][type=datetime-local]:focus,
.ag-theme-balham textarea[class^=ag-]:focus {
  outline: none;
  -webkit-box-shadow: 0 0 2px 1px #719ECE;
          box-shadow: 0 0 2px 1px #719ECE;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham input[class^=ag-]:not([type]):invalid,
.ag-theme-balham input[class^=ag-][type=text]:invalid,
.ag-theme-balham input[class^=ag-][type=number]:invalid,
.ag-theme-balham input[class^=ag-][type=tel]:invalid,
.ag-theme-balham input[class^=ag-][type=date]:invalid,
.ag-theme-balham input[class^=ag-][type=datetime-local]:invalid,
.ag-theme-balham textarea[class^=ag-]:invalid {
  border-width: 2px;
  border-style: solid;
  border-color: #e02525;
  border-color: var(--ag-input-border-color-invalid, var(--ag-invalid-color, #e02525));
}
.ag-theme-balham input[class^=ag-][type=number] {
  -moz-appearance: textfield;
}
.ag-theme-balham input[class^=ag-][type=number]::-webkit-outer-spin-button, .ag-theme-balham input[class^=ag-][type=number]::-webkit-inner-spin-button {
  -webkit-appearance: none;
  margin: 0;
}
.ag-theme-balham input[class^=ag-][type=range] {
  padding: 0;
}
.ag-theme-balham input[class^=ag-][type=button]:focus, .ag-theme-balham button[class^=ag-]:focus {
  -webkit-box-shadow: 0 0 2px 1px #719ECE;
          box-shadow: 0 0 2px 1px #719ECE;
}
.ag-theme-balham .ag-drag-handle {
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-list-item, .ag-theme-balham .ag-virtual-list-item {
  height: 24px;
}
.ag-theme-balham .ag-keyboard-focus .ag-virtual-list-item:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-virtual-list-item:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-select-list {
  background-color: white;
  background-color: var(--ag-background-color, white);
  overflow-y: auto;
  overflow-x: hidden;
}
.ag-theme-balham .ag-list-item {
  display: -webkit-box;
  display: flex;
  -webkit-box-align: center;
          align-items: center;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
.ag-theme-balham .ag-list-item.ag-active-item {
  background-color: #ecf0f1;
  background-color: var(--ag-row-hover-color, #ecf0f1);
}
.ag-theme-balham .ag-select-list-item {
  padding-left: 4px;
  padding-right: 4px;
  cursor: default;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
}
.ag-theme-balham .ag-select-list-item span {
  white-space: nowrap;
  text-overflow: ellipsis;
  overflow: hidden;
}
.ag-theme-balham .ag-select .ag-picker-field-wrapper {
  background-color: white;
  background-color: var(--ag-background-color, white);
  min-height: 24px;
  cursor: default;
}
.ag-theme-balham .ag-select.ag-disabled .ag-picker-field-wrapper:focus {
  -webkit-box-shadow: none;
          box-shadow: none;
}
.ag-theme-balham .ag-select:not(.ag-cell-editor) {
  height: 24px;
}
.ag-theme-balham .ag-select .ag-picker-field-display {
  margin: 4px;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
.ag-theme-balham .ag-select .ag-picker-field-icon {
  display: -webkit-box;
  display: flex;
  -webkit-box-align: center;
          align-items: center;
}
.ag-theme-balham .ag-select.ag-disabled {
  opacity: 0.5;
}
.ag-theme-balham .ag-rich-select {
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
}
.ag-theme-balham .ag-rich-select-list {
  width: 100%;
  min-width: 200px;
  height: 182px;
}
.ag-theme-balham .ag-rich-select-value {
  padding: 0 4px 0 12px;
  height: 28px;
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
}
.ag-theme-balham .ag-rich-select-virtual-list-item {
  cursor: default;
  height: 24px;
}
.ag-theme-balham .ag-rich-select-virtual-list-item:hover {
  background-color: #ecf0f1;
  background-color: var(--ag-row-hover-color, #ecf0f1);
}
.ag-theme-balham .ag-rich-select-row {
  padding-left: 12px;
}
.ag-theme-balham .ag-rich-select-row-selected {
  background-color: #b7e4ff;
  background-color: var(--ag-selected-row-background-color, #b7e4ff);
}
.ag-theme-balham .ag-row-drag,
.ag-theme-balham .ag-selection-checkbox,
.ag-theme-balham .ag-group-expanded,
.ag-theme-balham .ag-group-contracted {
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-ltr .ag-row-drag, .ag-theme-balham .ag-ltr .ag-selection-checkbox, .ag-theme-balham .ag-ltr .ag-group-expanded, .ag-theme-balham .ag-ltr .ag-group-contracted {
  margin-right: 12px;
}

.ag-theme-balham .ag-rtl .ag-row-drag, .ag-theme-balham .ag-rtl .ag-selection-checkbox, .ag-theme-balham .ag-rtl .ag-group-expanded, .ag-theme-balham .ag-rtl .ag-group-contracted {
  margin-left: 12px;
}

.ag-theme-balham .ag-cell-wrapper > *:not(.ag-cell-value):not(.ag-group-value) {
  height: min(var(--ag-line-height, 26px), 26px);
  display: -webkit-box;
  display: flex;
  -webkit-box-align: center;
          align-items: center;
  -webkit-box-flex: 0;
          flex: none;
}
.ag-theme-balham .ag-group-expanded,
.ag-theme-balham .ag-group-contracted {
  cursor: pointer;
}
.ag-theme-balham .ag-group-title-bar-icon {
  cursor: pointer;
  -webkit-box-flex: 0;
          flex: none;
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-ltr .ag-group-child-count {
  margin-left: 2px;
}

.ag-theme-balham .ag-rtl .ag-group-child-count {
  margin-right: 2px;
}

.ag-theme-balham .ag-group-title-bar {
  background-color: #e2e9eb;
  background-color: var(--ag-subheader-background-color, #e2e9eb);
  padding: 4px;
}
.ag-theme-balham .ag-group-toolbar {
  padding: 4px;
}
.ag-theme-balham .ag-disabled-group-title-bar, .ag-theme-balham .ag-disabled-group-container {
  opacity: 0.5;
}
.ag-theme-balham .group-item {
  margin: 2px 0;
}
.ag-theme-balham .ag-label {
  white-space: nowrap;
}
.ag-theme-balham .ag-ltr .ag-label {
  margin-right: 4px;
}

.ag-theme-balham .ag-rtl .ag-label {
  margin-left: 4px;
}

.ag-theme-balham .ag-label-align-top .ag-label {
  margin-bottom: 2px;
}
.ag-theme-balham .ag-ltr .ag-slider-field, .ag-theme-balham .ag-ltr .ag-angle-select-field {
  margin-right: 8px;
}

.ag-theme-balham .ag-rtl .ag-slider-field, .ag-theme-balham .ag-rtl .ag-angle-select-field {
  margin-left: 8px;
}

.ag-theme-balham .ag-angle-select-parent-circle {
  width: 24px;
  height: 24px;
  border-radius: 12px;
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  background-color: white;
  background-color: var(--ag-background-color, white);
}
.ag-theme-balham .ag-angle-select-child-circle {
  top: 4px;
  left: 12px;
  width: 6px;
  height: 6px;
  margin-left: -3px;
  margin-top: -4px;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.54);
  background-color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-picker-field-wrapper {
  border: 1px solid;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  border-radius: 5px;
}
.ag-theme-balham .ag-picker-field-wrapper:focus {
  -webkit-box-shadow: 0 0 2px 1px #719ECE;
          box-shadow: 0 0 2px 1px #719ECE;
}
.ag-theme-balham .ag-picker-field-button {
  background-color: white;
  background-color: var(--ag-background-color, white);
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-dialog.ag-color-dialog {
  border-radius: 5px;
}
.ag-theme-balham .ag-color-picker .ag-picker-field-display {
  height: 16px;
}
.ag-theme-balham .ag-color-panel {
  padding: 4px;
}
.ag-theme-balham .ag-spectrum-color {
  background-color: rgb(255, 0, 0);
  border-radius: 2px;
}
.ag-theme-balham .ag-spectrum-tools {
  padding: 10px;
}
.ag-theme-balham .ag-spectrum-sat {
  background-image: -webkit-gradient(linear, left top, right top, from(white), to(rgba(204, 154, 129, 0)));
  background-image: linear-gradient(to right, white, rgba(204, 154, 129, 0));
}
.ag-theme-balham .ag-spectrum-val {
  background-image: -webkit-gradient(linear, left bottom, left top, from(black), to(rgba(204, 154, 129, 0)));
  background-image: linear-gradient(to top, black, rgba(204, 154, 129, 0));
}
.ag-theme-balham .ag-spectrum-dragger {
  border-radius: 12px;
  height: 12px;
  width: 12px;
  border: 1px solid white;
  background: black;
  -webkit-box-shadow: 0 0 2px 0px rgba(0, 0, 0, 0.24);
          box-shadow: 0 0 2px 0px rgba(0, 0, 0, 0.24);
}
.ag-theme-balham .ag-spectrum-hue-background {
  border-radius: 2px;
}
.ag-theme-balham .ag-spectrum-alpha-background {
  border-radius: 2px;
}
.ag-theme-balham .ag-spectrum-tool {
  margin-bottom: 10px;
  height: 11px;
  border-radius: 2px;
}
.ag-theme-balham .ag-spectrum-slider {
  margin-top: -12px;
  width: 13px;
  height: 13px;
  border-radius: 13px;
  background-color: rgb(248, 248, 248);
  -webkit-box-shadow: 0 1px 4px 0 rgba(0, 0, 0, 0.37);
          box-shadow: 0 1px 4px 0 rgba(0, 0, 0, 0.37);
}
.ag-theme-balham .ag-recent-color {
  margin: 0 3px;
}
.ag-theme-balham .ag-recent-color:first-child {
  margin-left: 0;
}
.ag-theme-balham .ag-recent-color:last-child {
  margin-right: 0;
}
.ag-theme-balham.ag-dnd-ghost {
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  background: white;
  background: var(--ag-background-color, white);
  border-radius: 2px;
  -webkit-box-shadow: none;
          box-shadow: none;
  padding: 4px;
  overflow: hidden;
  text-overflow: ellipsis;
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
  height: 32px !important;
  line-height: 32px;
  margin: 0;
  padding: 0 8px;
  -webkit-transform: translateY(8px);
          transform: translateY(8px);
}
.ag-theme-balham .ag-dnd-ghost-icon {
  margin-right: 4px;
  color: #000;
  color: var(--ag-foreground-color, #000);
}
.ag-theme-balham .ag-popup-child:not(.ag-tooltip-custom) {
  -webkit-box-shadow: 5px 5px 10px rgba(0, 0, 0, 0.3);
          box-shadow: 5px 5px 10px rgba(0, 0, 0, 0.3);
}
.ag-dragging-range-handle .ag-theme-balham .ag-dialog, .ag-dragging-fill-handle .ag-theme-balham .ag-dialog {
  opacity: 0.7;
  pointer-events: none;
}
.ag-theme-balham .ag-dialog {
  border-radius: 2px;
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-panel {
  background-color: white;
  background-color: var(--ag-background-color, white);
}
.ag-theme-balham .ag-panel-title-bar {
  background-color: #f5f7f7;
  background-color: var(--ag-header-background-color, #f5f7f7);
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-header-foreground-color, var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54)));
  height: 32px;
  padding: 4px 12px;
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-ltr .ag-panel-title-bar-button {
  margin-left: 4px;
}

.ag-theme-balham .ag-rtl .ag-panel-title-bar-button {
  margin-right: 4px;
}

.ag-theme-balham .ag-tooltip {
  background-color: #f5f7f7;
  background-color: var(--ag-header-background-color, #f5f7f7);
  color: #000;
  color: var(--ag-foreground-color, #000);
  padding: 4px;
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  border-radius: 2px;
  -webkit-transition: opacity 1s;
  transition: opacity 1s;
  white-space: normal;
}
.ag-theme-balham .ag-tooltip.ag-tooltip-hiding {
  opacity: 0;
}
.ag-theme-balham .ag-tooltip-custom {
  -webkit-transition: opacity 1s;
  transition: opacity 1s;
}
.ag-theme-balham .ag-tooltip-custom.ag-tooltip-hiding {
  opacity: 0;
}
.ag-theme-balham .ag-ltr .ag-column-select-indent-1 {
  padding-left: 20px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-1 {
  padding-right: 20px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-2 {
  padding-left: 40px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-2 {
  padding-right: 40px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-3 {
  padding-left: 60px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-3 {
  padding-right: 60px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-4 {
  padding-left: 80px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-4 {
  padding-right: 80px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-5 {
  padding-left: 100px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-5 {
  padding-right: 100px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-6 {
  padding-left: 120px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-6 {
  padding-right: 120px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-7 {
  padding-left: 140px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-7 {
  padding-right: 140px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-8 {
  padding-left: 160px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-8 {
  padding-right: 160px;
}

.ag-theme-balham .ag-ltr .ag-column-select-indent-9 {
  padding-left: 180px;
}

.ag-theme-balham .ag-rtl .ag-column-select-indent-9 {
  padding-right: 180px;
}

.ag-theme-balham .ag-column-select-header-icon {
  cursor: pointer;
}
.ag-theme-balham .ag-keyboard-focus .ag-column-select-header-icon:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-column-select-header-icon:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 0px;
  left: 0px;
  display: block;
  width: calc(100% - 0px);
  height: calc(100% - 0px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-ltr .ag-column-group-icons:not(:last-child), .ag-theme-balham .ag-ltr .ag-column-select-header-icon:not(:last-child), .ag-theme-balham .ag-ltr .ag-column-select-header-checkbox:not(:last-child), .ag-theme-balham .ag-ltr .ag-column-select-header-filter-wrapper:not(:last-child), .ag-theme-balham .ag-ltr .ag-column-select-checkbox:not(:last-child), .ag-theme-balham .ag-ltr .ag-column-select-column-drag-handle:not(:last-child), .ag-theme-balham .ag-ltr .ag-column-select-column-group-drag-handle:not(:last-child), .ag-theme-balham .ag-ltr .ag-column-select-column-label:not(:last-child) {
  margin-right: 8px;
}

.ag-theme-balham .ag-rtl .ag-column-group-icons:not(:last-child), .ag-theme-balham .ag-rtl .ag-column-select-header-icon:not(:last-child), .ag-theme-balham .ag-rtl .ag-column-select-header-checkbox:not(:last-child), .ag-theme-balham .ag-rtl .ag-column-select-header-filter-wrapper:not(:last-child), .ag-theme-balham .ag-rtl .ag-column-select-checkbox:not(:last-child), .ag-theme-balham .ag-rtl .ag-column-select-column-drag-handle:not(:last-child), .ag-theme-balham .ag-rtl .ag-column-select-column-group-drag-handle:not(:last-child), .ag-theme-balham .ag-rtl .ag-column-select-column-label:not(:last-child) {
  margin-left: 8px;
}

.ag-theme-balham .ag-keyboard-focus .ag-column-select-virtual-list-item:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-column-select-virtual-list-item:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 1px;
  left: 1px;
  display: block;
  width: calc(100% - 2px);
  height: calc(100% - 2px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-column-select-column-group:not(:last-child),
.ag-theme-balham .ag-column-select-column:not(:last-child) {
  margin-bottom: 4px;
}
.ag-theme-balham .ag-column-select-column-readonly,
.ag-theme-balham .ag-column-select-column-group-readonly {
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
  pointer-events: none;
}
.ag-theme-balham .ag-ltr .ag-column-select-add-group-indent {
  margin-left: 24px;
}

.ag-theme-balham .ag-rtl .ag-column-select-add-group-indent {
  margin-right: 24px;
}

.ag-theme-balham .ag-column-select-virtual-list-viewport {
  padding: 3px 0px;
}
.ag-theme-balham .ag-column-select-virtual-list-item {
  padding: 0 6px;
}
.ag-theme-balham .ag-rtl {
  text-align: right;
}
.ag-theme-balham .ag-root-wrapper {
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-1 {
  padding-left: 40px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-1 {
  padding-right: 40px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-1 {
  padding-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-1 {
  padding-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row-level-1 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-1 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-2 {
  padding-left: 68px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-2 {
  padding-right: 68px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-2 {
  padding-left: 56px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-2 {
  padding-right: 56px;
}

.ag-theme-balham .ag-ltr .ag-row-level-2 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-2 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-3 {
  padding-left: 96px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-3 {
  padding-right: 96px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-3 {
  padding-left: 84px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-3 {
  padding-right: 84px;
}

.ag-theme-balham .ag-ltr .ag-row-level-3 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-3 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-4 {
  padding-left: 124px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-4 {
  padding-right: 124px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-4 {
  padding-left: 112px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-4 {
  padding-right: 112px;
}

.ag-theme-balham .ag-ltr .ag-row-level-4 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-4 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-5 {
  padding-left: 152px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-5 {
  padding-right: 152px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-5 {
  padding-left: 140px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-5 {
  padding-right: 140px;
}

.ag-theme-balham .ag-ltr .ag-row-level-5 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-5 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-6 {
  padding-left: 180px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-6 {
  padding-right: 180px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-6 {
  padding-left: 168px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-6 {
  padding-right: 168px;
}

.ag-theme-balham .ag-ltr .ag-row-level-6 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-6 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-7 {
  padding-left: 208px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-7 {
  padding-right: 208px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-7 {
  padding-left: 196px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-7 {
  padding-right: 196px;
}

.ag-theme-balham .ag-ltr .ag-row-level-7 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-7 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-8 {
  padding-left: 236px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-8 {
  padding-right: 236px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-8 {
  padding-left: 224px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-8 {
  padding-right: 224px;
}

.ag-theme-balham .ag-ltr .ag-row-level-8 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-8 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-9 {
  padding-left: 264px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-9 {
  padding-right: 264px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-9 {
  padding-left: 252px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-9 {
  padding-right: 252px;
}

.ag-theme-balham .ag-ltr .ag-row-level-9 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-9 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-10 {
  padding-left: 292px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-10 {
  padding-right: 292px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-10 {
  padding-left: 280px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-10 {
  padding-right: 280px;
}

.ag-theme-balham .ag-ltr .ag-row-level-10 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-10 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-11 {
  padding-left: 320px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-11 {
  padding-right: 320px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-11 {
  padding-left: 308px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-11 {
  padding-right: 308px;
}

.ag-theme-balham .ag-ltr .ag-row-level-11 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-11 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-12 {
  padding-left: 348px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-12 {
  padding-right: 348px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-12 {
  padding-left: 336px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-12 {
  padding-right: 336px;
}

.ag-theme-balham .ag-ltr .ag-row-level-12 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-12 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-13 {
  padding-left: 376px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-13 {
  padding-right: 376px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-13 {
  padding-left: 364px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-13 {
  padding-right: 364px;
}

.ag-theme-balham .ag-ltr .ag-row-level-13 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-13 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-14 {
  padding-left: 404px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-14 {
  padding-right: 404px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-14 {
  padding-left: 392px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-14 {
  padding-right: 392px;
}

.ag-theme-balham .ag-ltr .ag-row-level-14 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-14 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-15 {
  padding-left: 432px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-15 {
  padding-right: 432px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-15 {
  padding-left: 420px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-15 {
  padding-right: 420px;
}

.ag-theme-balham .ag-ltr .ag-row-level-15 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-15 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-16 {
  padding-left: 460px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-16 {
  padding-right: 460px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-16 {
  padding-left: 448px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-16 {
  padding-right: 448px;
}

.ag-theme-balham .ag-ltr .ag-row-level-16 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-16 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-17 {
  padding-left: 488px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-17 {
  padding-right: 488px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-17 {
  padding-left: 476px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-17 {
  padding-right: 476px;
}

.ag-theme-balham .ag-ltr .ag-row-level-17 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-17 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-18 {
  padding-left: 516px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-18 {
  padding-right: 516px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-18 {
  padding-left: 504px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-18 {
  padding-right: 504px;
}

.ag-theme-balham .ag-ltr .ag-row-level-18 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-18 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-19 {
  padding-left: 544px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-19 {
  padding-right: 544px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-19 {
  padding-left: 532px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-19 {
  padding-right: 532px;
}

.ag-theme-balham .ag-ltr .ag-row-level-19 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-19 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-20 {
  padding-left: 572px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-20 {
  padding-right: 572px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-20 {
  padding-left: 560px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-20 {
  padding-right: 560px;
}

.ag-theme-balham .ag-ltr .ag-row-level-20 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-20 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-21 {
  padding-left: 600px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-21 {
  padding-right: 600px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-21 {
  padding-left: 588px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-21 {
  padding-right: 588px;
}

.ag-theme-balham .ag-ltr .ag-row-level-21 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-21 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-22 {
  padding-left: 628px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-22 {
  padding-right: 628px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-22 {
  padding-left: 616px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-22 {
  padding-right: 616px;
}

.ag-theme-balham .ag-ltr .ag-row-level-22 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-22 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-23 {
  padding-left: 656px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-23 {
  padding-right: 656px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-23 {
  padding-left: 644px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-23 {
  padding-right: 644px;
}

.ag-theme-balham .ag-ltr .ag-row-level-23 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-23 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-24 {
  padding-left: 684px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-24 {
  padding-right: 684px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-24 {
  padding-left: 672px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-24 {
  padding-right: 672px;
}

.ag-theme-balham .ag-ltr .ag-row-level-24 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-24 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-25 {
  padding-left: 712px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-25 {
  padding-right: 712px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-25 {
  padding-left: 700px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-25 {
  padding-right: 700px;
}

.ag-theme-balham .ag-ltr .ag-row-level-25 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-25 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-26 {
  padding-left: 740px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-26 {
  padding-right: 740px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-26 {
  padding-left: 728px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-26 {
  padding-right: 728px;
}

.ag-theme-balham .ag-ltr .ag-row-level-26 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-26 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-27 {
  padding-left: 768px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-27 {
  padding-right: 768px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-27 {
  padding-left: 756px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-27 {
  padding-right: 756px;
}

.ag-theme-balham .ag-ltr .ag-row-level-27 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-27 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-28 {
  padding-left: 796px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-28 {
  padding-right: 796px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-28 {
  padding-left: 784px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-28 {
  padding-right: 784px;
}

.ag-theme-balham .ag-ltr .ag-row-level-28 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-28 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-29 {
  padding-left: 824px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-29 {
  padding-right: 824px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-29 {
  padding-left: 812px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-29 {
  padding-right: 812px;
}

.ag-theme-balham .ag-ltr .ag-row-level-29 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-29 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-30 {
  padding-left: 852px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-30 {
  padding-right: 852px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-30 {
  padding-left: 840px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-30 {
  padding-right: 840px;
}

.ag-theme-balham .ag-ltr .ag-row-level-30 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-30 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-31 {
  padding-left: 880px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-31 {
  padding-right: 880px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-31 {
  padding-left: 868px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-31 {
  padding-right: 868px;
}

.ag-theme-balham .ag-ltr .ag-row-level-31 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-31 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-32 {
  padding-left: 908px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-32 {
  padding-right: 908px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-32 {
  padding-left: 896px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-32 {
  padding-right: 896px;
}

.ag-theme-balham .ag-ltr .ag-row-level-32 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-32 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-33 {
  padding-left: 936px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-33 {
  padding-right: 936px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-33 {
  padding-left: 924px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-33 {
  padding-right: 924px;
}

.ag-theme-balham .ag-ltr .ag-row-level-33 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-33 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-34 {
  padding-left: 964px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-34 {
  padding-right: 964px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-34 {
  padding-left: 952px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-34 {
  padding-right: 952px;
}

.ag-theme-balham .ag-ltr .ag-row-level-34 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-34 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-35 {
  padding-left: 992px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-35 {
  padding-right: 992px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-35 {
  padding-left: 980px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-35 {
  padding-right: 980px;
}

.ag-theme-balham .ag-ltr .ag-row-level-35 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-35 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-36 {
  padding-left: 1020px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-36 {
  padding-right: 1020px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-36 {
  padding-left: 1008px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-36 {
  padding-right: 1008px;
}

.ag-theme-balham .ag-ltr .ag-row-level-36 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-36 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-37 {
  padding-left: 1048px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-37 {
  padding-right: 1048px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-37 {
  padding-left: 1036px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-37 {
  padding-right: 1036px;
}

.ag-theme-balham .ag-ltr .ag-row-level-37 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-37 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-38 {
  padding-left: 1076px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-38 {
  padding-right: 1076px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-38 {
  padding-left: 1064px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-38 {
  padding-right: 1064px;
}

.ag-theme-balham .ag-ltr .ag-row-level-38 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-38 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-39 {
  padding-left: 1104px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-39 {
  padding-right: 1104px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-39 {
  padding-left: 1092px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-39 {
  padding-right: 1092px;
}

.ag-theme-balham .ag-ltr .ag-row-level-39 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-39 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-40 {
  padding-left: 1132px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-40 {
  padding-right: 1132px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-40 {
  padding-left: 1120px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-40 {
  padding-right: 1120px;
}

.ag-theme-balham .ag-ltr .ag-row-level-40 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-40 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-41 {
  padding-left: 1160px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-41 {
  padding-right: 1160px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-41 {
  padding-left: 1148px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-41 {
  padding-right: 1148px;
}

.ag-theme-balham .ag-ltr .ag-row-level-41 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-41 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-42 {
  padding-left: 1188px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-42 {
  padding-right: 1188px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-42 {
  padding-left: 1176px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-42 {
  padding-right: 1176px;
}

.ag-theme-balham .ag-ltr .ag-row-level-42 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-42 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-43 {
  padding-left: 1216px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-43 {
  padding-right: 1216px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-43 {
  padding-left: 1204px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-43 {
  padding-right: 1204px;
}

.ag-theme-balham .ag-ltr .ag-row-level-43 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-43 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-44 {
  padding-left: 1244px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-44 {
  padding-right: 1244px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-44 {
  padding-left: 1232px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-44 {
  padding-right: 1232px;
}

.ag-theme-balham .ag-ltr .ag-row-level-44 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-44 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-45 {
  padding-left: 1272px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-45 {
  padding-right: 1272px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-45 {
  padding-left: 1260px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-45 {
  padding-right: 1260px;
}

.ag-theme-balham .ag-ltr .ag-row-level-45 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-45 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-46 {
  padding-left: 1300px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-46 {
  padding-right: 1300px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-46 {
  padding-left: 1288px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-46 {
  padding-right: 1288px;
}

.ag-theme-balham .ag-ltr .ag-row-level-46 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-46 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-47 {
  padding-left: 1328px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-47 {
  padding-right: 1328px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-47 {
  padding-left: 1316px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-47 {
  padding-right: 1316px;
}

.ag-theme-balham .ag-ltr .ag-row-level-47 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-47 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-48 {
  padding-left: 1356px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-48 {
  padding-right: 1356px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-48 {
  padding-left: 1344px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-48 {
  padding-right: 1344px;
}

.ag-theme-balham .ag-ltr .ag-row-level-48 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-48 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-49 {
  padding-left: 1384px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-49 {
  padding-right: 1384px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-49 {
  padding-left: 1372px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-49 {
  padding-right: 1372px;
}

.ag-theme-balham .ag-ltr .ag-row-level-49 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-49 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-50 {
  padding-left: 1412px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-50 {
  padding-right: 1412px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-50 {
  padding-left: 1400px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-50 {
  padding-right: 1400px;
}

.ag-theme-balham .ag-ltr .ag-row-level-50 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-50 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-51 {
  padding-left: 1440px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-51 {
  padding-right: 1440px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-51 {
  padding-left: 1428px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-51 {
  padding-right: 1428px;
}

.ag-theme-balham .ag-ltr .ag-row-level-51 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-51 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-52 {
  padding-left: 1468px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-52 {
  padding-right: 1468px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-52 {
  padding-left: 1456px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-52 {
  padding-right: 1456px;
}

.ag-theme-balham .ag-ltr .ag-row-level-52 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-52 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-53 {
  padding-left: 1496px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-53 {
  padding-right: 1496px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-53 {
  padding-left: 1484px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-53 {
  padding-right: 1484px;
}

.ag-theme-balham .ag-ltr .ag-row-level-53 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-53 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-54 {
  padding-left: 1524px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-54 {
  padding-right: 1524px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-54 {
  padding-left: 1512px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-54 {
  padding-right: 1512px;
}

.ag-theme-balham .ag-ltr .ag-row-level-54 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-54 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-55 {
  padding-left: 1552px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-55 {
  padding-right: 1552px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-55 {
  padding-left: 1540px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-55 {
  padding-right: 1540px;
}

.ag-theme-balham .ag-ltr .ag-row-level-55 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-55 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-56 {
  padding-left: 1580px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-56 {
  padding-right: 1580px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-56 {
  padding-left: 1568px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-56 {
  padding-right: 1568px;
}

.ag-theme-balham .ag-ltr .ag-row-level-56 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-56 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-57 {
  padding-left: 1608px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-57 {
  padding-right: 1608px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-57 {
  padding-left: 1596px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-57 {
  padding-right: 1596px;
}

.ag-theme-balham .ag-ltr .ag-row-level-57 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-57 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-58 {
  padding-left: 1636px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-58 {
  padding-right: 1636px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-58 {
  padding-left: 1624px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-58 {
  padding-right: 1624px;
}

.ag-theme-balham .ag-ltr .ag-row-level-58 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-58 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-59 {
  padding-left: 1664px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-59 {
  padding-right: 1664px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-59 {
  padding-left: 1652px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-59 {
  padding-right: 1652px;
}

.ag-theme-balham .ag-ltr .ag-row-level-59 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-59 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-60 {
  padding-left: 1692px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-60 {
  padding-right: 1692px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-60 {
  padding-left: 1680px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-60 {
  padding-right: 1680px;
}

.ag-theme-balham .ag-ltr .ag-row-level-60 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-60 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-61 {
  padding-left: 1720px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-61 {
  padding-right: 1720px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-61 {
  padding-left: 1708px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-61 {
  padding-right: 1708px;
}

.ag-theme-balham .ag-ltr .ag-row-level-61 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-61 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-62 {
  padding-left: 1748px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-62 {
  padding-right: 1748px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-62 {
  padding-left: 1736px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-62 {
  padding-right: 1736px;
}

.ag-theme-balham .ag-ltr .ag-row-level-62 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-62 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-63 {
  padding-left: 1776px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-63 {
  padding-right: 1776px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-63 {
  padding-left: 1764px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-63 {
  padding-right: 1764px;
}

.ag-theme-balham .ag-ltr .ag-row-level-63 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-63 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-64 {
  padding-left: 1804px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-64 {
  padding-right: 1804px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-64 {
  padding-left: 1792px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-64 {
  padding-right: 1792px;
}

.ag-theme-balham .ag-ltr .ag-row-level-64 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-64 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-65 {
  padding-left: 1832px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-65 {
  padding-right: 1832px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-65 {
  padding-left: 1820px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-65 {
  padding-right: 1820px;
}

.ag-theme-balham .ag-ltr .ag-row-level-65 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-65 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-66 {
  padding-left: 1860px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-66 {
  padding-right: 1860px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-66 {
  padding-left: 1848px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-66 {
  padding-right: 1848px;
}

.ag-theme-balham .ag-ltr .ag-row-level-66 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-66 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-67 {
  padding-left: 1888px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-67 {
  padding-right: 1888px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-67 {
  padding-left: 1876px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-67 {
  padding-right: 1876px;
}

.ag-theme-balham .ag-ltr .ag-row-level-67 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-67 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-68 {
  padding-left: 1916px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-68 {
  padding-right: 1916px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-68 {
  padding-left: 1904px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-68 {
  padding-right: 1904px;
}

.ag-theme-balham .ag-ltr .ag-row-level-68 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-68 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-69 {
  padding-left: 1944px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-69 {
  padding-right: 1944px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-69 {
  padding-left: 1932px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-69 {
  padding-right: 1932px;
}

.ag-theme-balham .ag-ltr .ag-row-level-69 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-69 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-70 {
  padding-left: 1972px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-70 {
  padding-right: 1972px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-70 {
  padding-left: 1960px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-70 {
  padding-right: 1960px;
}

.ag-theme-balham .ag-ltr .ag-row-level-70 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-70 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-71 {
  padding-left: 2000px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-71 {
  padding-right: 2000px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-71 {
  padding-left: 1988px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-71 {
  padding-right: 1988px;
}

.ag-theme-balham .ag-ltr .ag-row-level-71 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-71 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-72 {
  padding-left: 2028px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-72 {
  padding-right: 2028px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-72 {
  padding-left: 2016px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-72 {
  padding-right: 2016px;
}

.ag-theme-balham .ag-ltr .ag-row-level-72 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-72 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-73 {
  padding-left: 2056px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-73 {
  padding-right: 2056px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-73 {
  padding-left: 2044px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-73 {
  padding-right: 2044px;
}

.ag-theme-balham .ag-ltr .ag-row-level-73 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-73 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-74 {
  padding-left: 2084px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-74 {
  padding-right: 2084px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-74 {
  padding-left: 2072px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-74 {
  padding-right: 2072px;
}

.ag-theme-balham .ag-ltr .ag-row-level-74 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-74 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-75 {
  padding-left: 2112px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-75 {
  padding-right: 2112px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-75 {
  padding-left: 2100px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-75 {
  padding-right: 2100px;
}

.ag-theme-balham .ag-ltr .ag-row-level-75 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-75 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-76 {
  padding-left: 2140px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-76 {
  padding-right: 2140px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-76 {
  padding-left: 2128px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-76 {
  padding-right: 2128px;
}

.ag-theme-balham .ag-ltr .ag-row-level-76 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-76 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-77 {
  padding-left: 2168px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-77 {
  padding-right: 2168px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-77 {
  padding-left: 2156px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-77 {
  padding-right: 2156px;
}

.ag-theme-balham .ag-ltr .ag-row-level-77 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-77 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-78 {
  padding-left: 2196px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-78 {
  padding-right: 2196px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-78 {
  padding-left: 2184px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-78 {
  padding-right: 2184px;
}

.ag-theme-balham .ag-ltr .ag-row-level-78 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-78 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-79 {
  padding-left: 2224px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-79 {
  padding-right: 2224px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-79 {
  padding-left: 2212px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-79 {
  padding-right: 2212px;
}

.ag-theme-balham .ag-ltr .ag-row-level-79 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-79 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-80 {
  padding-left: 2252px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-80 {
  padding-right: 2252px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-80 {
  padding-left: 2240px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-80 {
  padding-right: 2240px;
}

.ag-theme-balham .ag-ltr .ag-row-level-80 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-80 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-81 {
  padding-left: 2280px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-81 {
  padding-right: 2280px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-81 {
  padding-left: 2268px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-81 {
  padding-right: 2268px;
}

.ag-theme-balham .ag-ltr .ag-row-level-81 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-81 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-82 {
  padding-left: 2308px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-82 {
  padding-right: 2308px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-82 {
  padding-left: 2296px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-82 {
  padding-right: 2296px;
}

.ag-theme-balham .ag-ltr .ag-row-level-82 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-82 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-83 {
  padding-left: 2336px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-83 {
  padding-right: 2336px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-83 {
  padding-left: 2324px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-83 {
  padding-right: 2324px;
}

.ag-theme-balham .ag-ltr .ag-row-level-83 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-83 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-84 {
  padding-left: 2364px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-84 {
  padding-right: 2364px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-84 {
  padding-left: 2352px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-84 {
  padding-right: 2352px;
}

.ag-theme-balham .ag-ltr .ag-row-level-84 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-84 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-85 {
  padding-left: 2392px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-85 {
  padding-right: 2392px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-85 {
  padding-left: 2380px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-85 {
  padding-right: 2380px;
}

.ag-theme-balham .ag-ltr .ag-row-level-85 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-85 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-86 {
  padding-left: 2420px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-86 {
  padding-right: 2420px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-86 {
  padding-left: 2408px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-86 {
  padding-right: 2408px;
}

.ag-theme-balham .ag-ltr .ag-row-level-86 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-86 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-87 {
  padding-left: 2448px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-87 {
  padding-right: 2448px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-87 {
  padding-left: 2436px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-87 {
  padding-right: 2436px;
}

.ag-theme-balham .ag-ltr .ag-row-level-87 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-87 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-88 {
  padding-left: 2476px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-88 {
  padding-right: 2476px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-88 {
  padding-left: 2464px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-88 {
  padding-right: 2464px;
}

.ag-theme-balham .ag-ltr .ag-row-level-88 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-88 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-89 {
  padding-left: 2504px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-89 {
  padding-right: 2504px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-89 {
  padding-left: 2492px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-89 {
  padding-right: 2492px;
}

.ag-theme-balham .ag-ltr .ag-row-level-89 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-89 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-90 {
  padding-left: 2532px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-90 {
  padding-right: 2532px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-90 {
  padding-left: 2520px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-90 {
  padding-right: 2520px;
}

.ag-theme-balham .ag-ltr .ag-row-level-90 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-90 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-91 {
  padding-left: 2560px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-91 {
  padding-right: 2560px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-91 {
  padding-left: 2548px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-91 {
  padding-right: 2548px;
}

.ag-theme-balham .ag-ltr .ag-row-level-91 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-91 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-92 {
  padding-left: 2588px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-92 {
  padding-right: 2588px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-92 {
  padding-left: 2576px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-92 {
  padding-right: 2576px;
}

.ag-theme-balham .ag-ltr .ag-row-level-92 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-92 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-93 {
  padding-left: 2616px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-93 {
  padding-right: 2616px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-93 {
  padding-left: 2604px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-93 {
  padding-right: 2604px;
}

.ag-theme-balham .ag-ltr .ag-row-level-93 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-93 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-94 {
  padding-left: 2644px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-94 {
  padding-right: 2644px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-94 {
  padding-left: 2632px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-94 {
  padding-right: 2632px;
}

.ag-theme-balham .ag-ltr .ag-row-level-94 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-94 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-95 {
  padding-left: 2672px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-95 {
  padding-right: 2672px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-95 {
  padding-left: 2660px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-95 {
  padding-right: 2660px;
}

.ag-theme-balham .ag-ltr .ag-row-level-95 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-95 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-96 {
  padding-left: 2700px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-96 {
  padding-right: 2700px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-96 {
  padding-left: 2688px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-96 {
  padding-right: 2688px;
}

.ag-theme-balham .ag-ltr .ag-row-level-96 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-96 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-97 {
  padding-left: 2728px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-97 {
  padding-right: 2728px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-97 {
  padding-left: 2716px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-97 {
  padding-right: 2716px;
}

.ag-theme-balham .ag-ltr .ag-row-level-97 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-97 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-98 {
  padding-left: 2756px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-98 {
  padding-right: 2756px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-98 {
  padding-left: 2744px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-98 {
  padding-right: 2744px;
}

.ag-theme-balham .ag-ltr .ag-row-level-98 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-98 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row > .ag-cell-wrapper.ag-row-group-indent-99 {
  padding-left: 2784px;
}

.ag-theme-balham .ag-rtl .ag-row > .ag-cell-wrapper.ag-row-group-indent-99 {
  padding-right: 2784px;
}

.ag-theme-balham .ag-ltr .ag-row-group-indent-99 {
  padding-left: 2772px;
}

.ag-theme-balham .ag-rtl .ag-row-group-indent-99 {
  padding-right: 2772px;
}

.ag-theme-balham .ag-ltr .ag-row-level-99 .ag-pivot-leaf-group {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-level-99 .ag-pivot-leaf-group {
  margin-right: 28px;
}

.ag-theme-balham .ag-ltr .ag-row-group-leaf-indent {
  margin-left: 28px;
}

.ag-theme-balham .ag-rtl .ag-row-group-leaf-indent {
  margin-right: 28px;
}

.ag-theme-balham .ag-value-change-delta {
  padding-right: 2px;
}
.ag-theme-balham .ag-value-change-delta-up {
  color: #43a047;
  color: var(--ag-value-change-delta-up-color, #43a047);
}
.ag-theme-balham .ag-value-change-delta-down {
  color: #e53935;
  color: var(--ag-value-change-delta-down-color, #e53935);
}
.ag-theme-balham .ag-value-change-value {
  background-color: transparent;
  border-radius: 1px;
  padding-left: 1px;
  padding-right: 1px;
  -webkit-transition: background-color 1s;
  transition: background-color 1s;
}
.ag-theme-balham .ag-value-change-value-highlight {
  background-color: rgba(22, 160, 133, 0.5);
  background-color: var(--ag-value-change-value-highlight-background-color, rgba(22, 160, 133, 0.5));
  -webkit-transition: background-color 0.1s;
  transition: background-color 0.1s;
}
.ag-theme-balham .ag-cell-data-changed {
  background-color: rgba(22, 160, 133, 0.5) !important;
  background-color: var(--ag-value-change-value-highlight-background-color, rgba(22, 160, 133, 0.5)) !important;
}
.ag-theme-balham .ag-cell-data-changed-animation {
  background-color: transparent;
}
.ag-theme-balham .ag-cell-highlight {
  background-color: #0091ea !important;
  background-color: var(--ag-range-selection-highlight-color, var(--ag-balham-active-color, #0091ea)) !important;
}
.ag-theme-balham .ag-row {
  height: 28px;
  background-color: white;
  background-color: var(--ag-background-color, white);
  color: #000;
  color: var(--ag-data-color, var(--ag-foreground-color, #000));
  border-width: 1px;
  border-color: #d9dcde;
  border-color: var(--ag-row-border-color, #d9dcde);
  border-bottom-style: solid;
}
.ag-theme-balham .ag-row-highlight-above::after, .ag-theme-balham .ag-row-highlight-below::after {
  content: "";
  position: absolute;
  width: calc(100% - 1px);
  height: 1px;
  background-color: #0091ea;
  background-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
  left: 1px;
}
.ag-theme-balham .ag-row-highlight-above::after {
  top: -1px;
}
.ag-theme-balham .ag-row-highlight-above.ag-row-first::after {
  top: 0;
}
.ag-theme-balham .ag-row-highlight-below::after {
  bottom: 0px;
}
.ag-theme-balham .ag-row-odd {
  background-color: #fcfdfe;
  background-color: var(--ag-odd-row-background-color, #fcfdfe);
}
.ag-theme-balham .ag-body-horizontal-scroll:not(.ag-scrollbar-invisible) .ag-horizontal-left-spacer:not(.ag-scroller-corner) {
  border-right: solid 1px;
  border-right-color: #bdc3c7;
  border-right-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-body-horizontal-scroll:not(.ag-scrollbar-invisible) .ag-horizontal-right-spacer:not(.ag-scroller-corner) {
  border-left: solid 1px;
  border-left-color: #bdc3c7;
  border-left-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-row-hover {
  background-color: #ecf0f1;
  background-color: var(--ag-row-hover-color, #ecf0f1);
}
.ag-theme-balham .ag-column-hover {
  background-color: #ecf0f1;
  background-color: var(--ag-column-hover-color, #ecf0f1);
}
.ag-theme-balham .ag-ltr .ag-right-aligned-cell {
  text-align: right;
}

.ag-theme-balham .ag-rtl .ag-right-aligned-cell {
  text-align: left;
}

.ag-theme-balham .ag-ltr .ag-right-aligned-cell .ag-cell-value, .ag-theme-balham .ag-ltr .ag-right-aligned-cell .ag-group-value {
  margin-left: auto;
}

.ag-theme-balham .ag-rtl .ag-right-aligned-cell .ag-cell-value, .ag-theme-balham .ag-rtl .ag-right-aligned-cell .ag-group-value {
  margin-right: auto;
}

.ag-theme-balham .ag-cell, .ag-theme-balham .ag-full-width-row .ag-cell-wrapper.ag-row-group {
  border: 1px solid transparent;
  line-height: min(var(--ag-line-height, 26px), 26px);
  padding-left: 11px;
  padding-right: 11px;
  -webkit-font-smoothing: subpixel-antialiased;
}
.ag-theme-balham .ag-row > .ag-cell-wrapper {
  padding-left: 11px;
  padding-right: 11px;
}
.ag-theme-balham .ag-row-dragging {
  cursor: move;
  opacity: 0.5;
}
.ag-theme-balham .ag-cell-inline-editing {
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  background: white;
  background: var(--ag-background-color, white);
  border-radius: 2px;
  -webkit-box-shadow: none;
          box-shadow: none;
  padding: 4px;
  padding: 0;
  height: 28px;
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
}
.ag-theme-balham .ag-popup-editor {
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  background: white;
  background: var(--ag-background-color, white);
  border-radius: 2px;
  -webkit-box-shadow: none;
          box-shadow: none;
  padding: 4px;
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
  padding: 0;
}
.ag-theme-balham .ag-large-text-input {
  height: auto;
  padding: 12px;
}
.ag-theme-balham .ag-details-row {
  padding: 20px;
  background-color: white;
  background-color: var(--ag-background-color, white);
}
.ag-theme-balham .ag-layout-auto-height .ag-center-cols-clipper, .ag-theme-balham .ag-layout-auto-height .ag-center-cols-container, .ag-theme-balham .ag-layout-print .ag-center-cols-clipper, .ag-theme-balham .ag-layout-print .ag-center-cols-container {
  min-height: 50px;
}
.ag-theme-balham .ag-overlay-loading-wrapper {
  background-color: rgba(255, 255, 255, 0.66);
  background-color: var(--ag-modal-overlay-background-color, rgba(255, 255, 255, 0.66));
}
.ag-theme-balham .ag-overlay-loading-center {
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  background: white;
  background: var(--ag-background-color, white);
  border-radius: 2px;
  -webkit-box-shadow: none;
          box-shadow: none;
  padding: 4px;
}
.ag-theme-balham .ag-overlay-no-rows-wrapper.ag-layout-auto-height {
  padding-top: 30px;
}
.ag-theme-balham .ag-loading {
  padding-left: 12px;
  display: -webkit-box;
  display: flex;
  height: 100%;
  -webkit-box-align: center;
          align-items: center;
}
.ag-theme-balham .ag-loading-icon {
  padding-right: 12px;
}
.ag-theme-balham .ag-icon-loading {
  -webkit-animation-name: spin;
          animation-name: spin;
  -webkit-animation-duration: 1000ms;
          animation-duration: 1000ms;
  -webkit-animation-iteration-count: infinite;
          animation-iteration-count: infinite;
  -webkit-animation-timing-function: linear;
          animation-timing-function: linear;
}
@-webkit-keyframes spin {
  from {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg);
  }
  to {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg);
  }
}
@keyframes spin {
  from {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg);
  }
  to {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg);
  }
}
.ag-theme-balham .ag-floating-top {
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-floating-bottom {
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-ltr .ag-cell {
  border-right: solid transparent;
}

.ag-theme-balham .ag-rtl .ag-cell {
  border-left: solid transparent;
}

.ag-theme-balham .ag-ltr .ag-cell {
  border-right-width: 1px;
}

.ag-theme-balham .ag-rtl .ag-cell {
  border-left-width: 1px;
}

.ag-theme-balham .ag-cell.ag-cell-first-right-pinned:not(.ag-cell-range-left):not(.ag-cell-range-single-cell) {
  border-left: solid 1px;
  border-left-color: #bdc3c7;
  border-left-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-cell.ag-cell-last-left-pinned:not(.ag-cell-range-right):not(.ag-cell-range-single-cell) {
  border-right: solid 1px;
  border-right-color: #bdc3c7;
  border-right-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-row-selected {
  background-color: #b7e4ff;
  background-color: var(--ag-selected-row-background-color, #b7e4ff);
}
.ag-theme-balham .ag-cell-range-selected:not(.ag-cell-focus),
.ag-theme-balham .ag-body-viewport:not(.ag-has-focus) .ag-cell-range-single-cell:not(.ag-cell-inline-editing) {
  background-color: rgba(0, 145, 234, 0.2);
  background-color: var(--ag-range-selection-background-color, rgba(0, 145, 234, 0.2));
}
.ag-theme-balham .ag-cell-range-selected:not(.ag-cell-focus).ag-cell-range-chart,
.ag-theme-balham .ag-body-viewport:not(.ag-has-focus) .ag-cell-range-single-cell:not(.ag-cell-inline-editing).ag-cell-range-chart {
  background-color: rgba(0, 88, 255, 0.1) !important;
  background-color: var(--ag-range-selection-chart-background-color, rgba(0, 88, 255, 0.1)) !important;
}
.ag-theme-balham .ag-cell-range-selected:not(.ag-cell-focus).ag-cell-range-chart.ag-cell-range-chart-category,
.ag-theme-balham .ag-body-viewport:not(.ag-has-focus) .ag-cell-range-single-cell:not(.ag-cell-inline-editing).ag-cell-range-chart.ag-cell-range-chart-category {
  background-color: rgba(0, 255, 132, 0.1) !important;
  background-color: var(--ag-range-selection-chart-category-background-color, rgba(0, 255, 132, 0.1)) !important;
}
.ag-theme-balham .ag-cell-range-selected-1:not(.ag-cell-focus),
.ag-theme-balham .ag-root:not(.ag-context-menu-open) .ag-body-viewport:not(.ag-has-focus) .ag-cell-range-selected-1:not(.ag-cell-inline-editing) {
  background-color: rgba(0, 145, 234, 0.2);
  background-color: var(--ag-range-selection-background-color-1, var(--ag-range-selection-background-color, rgba(0, 145, 234, 0.2)));
}
.ag-theme-balham .ag-cell-range-selected-2:not(.ag-cell-focus),
.ag-theme-balham .ag-body-viewport:not(.ag-has-focus) .ag-cell-range-selected-2 {
  background-color: rgba(0, 145, 234, 0.36);
  background-color: var(--ag-range-selection-background-color-2, rgba(0, 145, 234, 0.36));
}
.ag-theme-balham .ag-cell-range-selected-3:not(.ag-cell-focus),
.ag-theme-balham .ag-body-viewport:not(.ag-has-focus) .ag-cell-range-selected-3 {
  background-color: rgba(0, 145, 234, 0.488);
  background-color: var(--ag-range-selection-background-color-3, rgba(0, 145, 234, 0.488));
}
.ag-theme-balham .ag-cell-range-selected-4:not(.ag-cell-focus),
.ag-theme-balham .ag-body-viewport:not(.ag-has-focus) .ag-cell-range-selected-4 {
  background-color: rgba(0, 145, 234, 0.5904);
  background-color: var(--ag-range-selection-background-color-4, rgba(0, 145, 234, 0.5904));
}
.ag-theme-balham .ag-cell.ag-cell-range-selected:not(.ag-cell-range-single-cell).ag-cell-range-top {
  border-top-color: #0091ea;
  border-top-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-cell.ag-cell-range-selected:not(.ag-cell-range-single-cell).ag-cell-range-right {
  border-right-color: #0091ea;
  border-right-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-cell.ag-cell-range-selected:not(.ag-cell-range-single-cell).ag-cell-range-bottom {
  border-bottom-color: #0091ea;
  border-bottom-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-cell.ag-cell-range-selected:not(.ag-cell-range-single-cell).ag-cell-range-left {
  border-left-color: #0091ea;
  border-left-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-ltr .ag-has-focus .ag-cell-focus:not(.ag-cell-range-selected),
.ag-theme-balham .ag-ltr .ag-context-menu-open .ag-cell-focus:not(.ag-cell-range-selected),
.ag-theme-balham .ag-ltr .ag-has-focus .ag-full-width-row.ag-row-focus .ag-cell-wrapper.ag-row-group,
.ag-theme-balham .ag-ltr .ag-cell-range-single-cell,
.ag-theme-balham .ag-ltr .ag-cell-range-single-cell.ag-cell-range-handle, .ag-theme-balham .ag-rtl .ag-has-focus .ag-cell-focus:not(.ag-cell-range-selected),
.ag-theme-balham .ag-rtl .ag-context-menu-open .ag-cell-focus:not(.ag-cell-range-selected),
.ag-theme-balham .ag-rtl .ag-has-focus .ag-full-width-row.ag-row-focus .ag-cell-wrapper.ag-row-group,
.ag-theme-balham .ag-rtl .ag-cell-range-single-cell,
.ag-theme-balham .ag-rtl .ag-cell-range-single-cell.ag-cell-range-handle {
  border: 1px solid;
  border-color: #0091ea;
  border-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
  outline: initial;
}
.ag-theme-balham .ag-cell.ag-selection-fill-top,
.ag-theme-balham .ag-cell.ag-selection-fill-top.ag-cell-range-selected {
  border-top: 1px dashed;
  border-top-color: #0091ea;
  border-top-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-ltr .ag-cell.ag-selection-fill-right, .ag-theme-balham .ag-ltr .ag-cell.ag-selection-fill-right.ag-cell-range-selected {
  border-right: 1px dashed;
  border-right-color: #0091ea;
  border-right-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}

.ag-theme-balham .ag-rtl .ag-cell.ag-selection-fill-right, .ag-theme-balham .ag-rtl .ag-cell.ag-selection-fill-right.ag-cell-range-selected {
  border-left: 1px dashed;
  border-left-color: #0091ea;
  border-left-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}

.ag-theme-balham .ag-cell.ag-selection-fill-bottom,
.ag-theme-balham .ag-cell.ag-selection-fill-bottom.ag-cell-range-selected {
  border-bottom: 1px dashed;
  border-bottom-color: #0091ea;
  border-bottom-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-ltr .ag-cell.ag-selection-fill-left, .ag-theme-balham .ag-ltr .ag-cell.ag-selection-fill-left.ag-cell-range-selected {
  border-left: 1px dashed;
  border-left-color: #0091ea;
  border-left-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}

.ag-theme-balham .ag-rtl .ag-cell.ag-selection-fill-left, .ag-theme-balham .ag-rtl .ag-cell.ag-selection-fill-left.ag-cell-range-selected {
  border-right: 1px dashed;
  border-right-color: #0091ea;
  border-right-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}

.ag-theme-balham .ag-range-handle, .ag-theme-balham .ag-fill-handle {
  position: absolute;
  width: 6px;
  height: 6px;
  bottom: -1px;
  background-color: #0091ea;
  background-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-ltr .ag-range-handle, .ag-theme-balham .ag-ltr .ag-fill-handle {
  right: -1px;
}

.ag-theme-balham .ag-rtl .ag-range-handle, .ag-theme-balham .ag-rtl .ag-fill-handle {
  left: -1px;
}

.ag-theme-balham .ag-fill-handle {
  cursor: cell;
}
.ag-theme-balham .ag-range-handle {
  cursor: nwse-resize;
}
.ag-theme-balham .ag-cell-inline-editing {
  border-color: #719ECE !important;
  border-color: var(--ag-input-focus-border-color, #719ECE) !important;
}
.ag-theme-balham .ag-menu {
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  background: white;
  background: var(--ag-background-color, white);
  border-radius: 2px;
  -webkit-box-shadow: none;
          box-shadow: none;
  padding: 4px;
  padding: 0;
}
.ag-theme-balham .ag-menu-list {
  cursor: default;
  padding: 4px 0;
}
.ag-theme-balham .ag-menu-separator {
  height: 9px;
}
.ag-theme-balham .ag-menu-separator-part::after {
  content: "";
  display: block;
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-menu-option-active, .ag-theme-balham .ag-compact-menu-option-active {
  background-color: #ecf0f1;
  background-color: var(--ag-row-hover-color, #ecf0f1);
}
.ag-theme-balham .ag-menu-option-part, .ag-theme-balham .ag-compact-menu-option-part {
  line-height: 16px;
  padding: 6px 0;
}
.ag-theme-balham .ag-menu-option-disabled, .ag-theme-balham .ag-compact-menu-option-disabled {
  opacity: 0.5;
}
.ag-theme-balham .ag-menu-option-icon, .ag-theme-balham .ag-compact-menu-option-icon {
  width: 16px;
}
.ag-theme-balham .ag-ltr .ag-menu-option-icon, .ag-theme-balham .ag-ltr .ag-compact-menu-option-icon {
  padding-left: 8px;
}

.ag-theme-balham .ag-rtl .ag-menu-option-icon, .ag-theme-balham .ag-rtl .ag-compact-menu-option-icon {
  padding-right: 8px;
}

.ag-theme-balham .ag-menu-option-text, .ag-theme-balham .ag-compact-menu-option-text {
  padding-left: 8px;
  padding-right: 8px;
}
.ag-theme-balham .ag-ltr .ag-menu-option-shortcut, .ag-theme-balham .ag-ltr .ag-compact-menu-option-shortcut {
  padding-right: 4px;
}

.ag-theme-balham .ag-rtl .ag-menu-option-shortcut, .ag-theme-balham .ag-rtl .ag-compact-menu-option-shortcut {
  padding-left: 4px;
}

.ag-theme-balham .ag-menu-option-popup-pointer, .ag-theme-balham .ag-compact-menu-option-popup-pointer {
  padding-right: 4px;
}
.ag-theme-balham .ag-tabs {
  min-width: 220px;
}
.ag-theme-balham .ag-tabs-header {
  width: 100%;
  display: -webkit-box;
  display: flex;
}
.ag-theme-balham .ag-tab {
  border-bottom: 0 solid transparent;
  display: -webkit-box;
  display: flex;
  -webkit-box-flex: 0;
          flex: none;
  -webkit-box-align: center;
          align-items: center;
  -webkit-box-pack: center;
          justify-content: center;
  cursor: pointer;
}
.ag-theme-balham .ag-keyboard-focus .ag-tab:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-tab:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-tab-selected {
  border-bottom-color: #0091ea;
  border-bottom-color: var(--ag-selected-tab-underline-color, var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea)));
}
.ag-theme-balham .ag-menu-header {
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-filter-separator {
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-menu:not(.ag-tabs) .ag-filter-select {
  min-width: 167px;
}
.ag-theme-balham .ag-tabs .ag-filter-select {
  min-width: 206px;
}
.ag-theme-balham .ag-filter-select .ag-picker-field-wrapper {
  width: 0;
}
.ag-theme-balham .ag-filter-condition-operator {
  height: 17px;
}
.ag-theme-balham .ag-ltr .ag-filter-condition-operator-or {
  margin-left: 8px;
}

.ag-theme-balham .ag-rtl .ag-filter-condition-operator-or {
  margin-right: 8px;
}

.ag-theme-balham .ag-set-filter-select-all {
  padding-top: 6px;
}
.ag-theme-balham .ag-set-filter-list, .ag-theme-balham .ag-filter-no-matches {
  height: 144px;
}
.ag-theme-balham .ag-set-filter-filter {
  margin-top: 6px;
  margin-left: 6px;
  margin-right: 6px;
}
.ag-theme-balham .ag-filter-to {
  margin-top: 4px;
}
.ag-theme-balham .ag-mini-filter {
  margin: 6px 6px;
}
.ag-theme-balham .ag-set-filter-item {
  margin: 0px 6px;
}
.ag-theme-balham .ag-ltr .ag-set-filter-item-value {
  margin-left: 6px;
}

.ag-theme-balham .ag-rtl .ag-set-filter-item-value {
  margin-right: 6px;
}

.ag-theme-balham .ag-filter-apply-panel {
  padding: 6px 6px;
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
}
.ag-theme-balham .ag-filter-apply-panel-button {
  line-height: 1.5;
}
.ag-theme-balham .ag-ltr .ag-filter-apply-panel-button {
  margin-left: 8px;
}

.ag-theme-balham .ag-rtl .ag-filter-apply-panel-button {
  margin-right: 8px;
}

.ag-theme-balham .ag-simple-filter-body-wrapper {
  padding: 6px 6px;
  padding-bottom: 2px;
}
.ag-theme-balham .ag-simple-filter-body-wrapper > * {
  margin-bottom: 4px;
}
.ag-theme-balham .ag-filter-no-matches {
  padding: 6px 6px;
}
.ag-theme-balham .ag-multi-filter-menu-item {
  margin: 4px 0;
}
.ag-theme-balham .ag-multi-filter-group-title-bar {
  padding: 8px 4px;
  background-color: transparent;
}
.ag-theme-balham .ag-keyboard-focus .ag-multi-filter-group-title-bar:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-multi-filter-group-title-bar:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-side-bar {
  position: relative;
}
.ag-theme-balham .ag-tool-panel-wrapper {
  width: 200px;
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
}
.ag-theme-balham .ag-side-buttons {
  padding-top: 16px;
  width: 20px;
  position: relative;
  color: #000;
  color: var(--ag-foreground-color, #000);
  overflow: hidden;
}
.ag-theme-balham button.ag-side-button-button {
  color: inherit;
  font-family: inherit;
  font-size: inherit;
  font-weight: inherit;
  line-height: inherit;
  background: transparent;
  padding: 8px 0 8px 0;
  width: calc(100% + 1px);
  margin: 0;
  min-height: 72px;
  background-position-y: center;
  background-position-x: center;
  background-repeat: no-repeat;
  border: none;
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham button.ag-side-button-button:focus {
  -webkit-box-shadow: none;
          box-shadow: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-side-button-button:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-side-button-button:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-selected .ag-side-button-button {
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-side-button-icon-wrapper {
  margin-bottom: 3px;
}
.ag-theme-balham .ag-ltr .ag-side-bar-left,
.ag-theme-balham .ag-rtl .ag-side-bar-right {
  border-right: solid 1px;
  border-right-color: #bdc3c7;
  border-right-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-ltr .ag-side-bar-left .ag-tool-panel-wrapper,
.ag-theme-balham .ag-rtl .ag-side-bar-right .ag-tool-panel-wrapper {
  border-left: solid 1px;
  border-left-color: #bdc3c7;
  border-left-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-ltr .ag-side-bar-left .ag-side-button-button,
.ag-theme-balham .ag-rtl .ag-side-bar-right .ag-side-button-button {
  border-right: 0 solid transparent;
  margin-right: -1px;
  padding-right: 1px;
}
.ag-theme-balham .ag-ltr .ag-side-bar-left .ag-selected .ag-side-button-button,
.ag-theme-balham .ag-rtl .ag-side-bar-right .ag-selected .ag-side-button-button {
  border-right-color: #0091ea;
  border-right-color: var(--ag-selected-tab-underline-color, var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea)));
}
.ag-theme-balham .ag-rtl .ag-side-bar-left,
.ag-theme-balham .ag-ltr .ag-side-bar-right {
  border-left: solid 1px;
  border-left-color: #bdc3c7;
  border-left-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-rtl .ag-side-bar-left .ag-tool-panel-wrapper,
.ag-theme-balham .ag-ltr .ag-side-bar-right .ag-tool-panel-wrapper {
  border-right: solid 1px;
  border-right-color: #bdc3c7;
  border-right-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-rtl .ag-side-bar-left .ag-side-button-button,
.ag-theme-balham .ag-ltr .ag-side-bar-right .ag-side-button-button {
  border-left: 0 solid transparent;
  margin-left: -1px;
  padding-left: 1px;
}
.ag-theme-balham .ag-rtl .ag-side-bar-left .ag-selected .ag-side-button-button,
.ag-theme-balham .ag-ltr .ag-side-bar-right .ag-selected .ag-side-button-button {
  border-left-color: #0091ea;
  border-left-color: var(--ag-selected-tab-underline-color, var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea)));
}
.ag-theme-balham .ag-filter-toolpanel-header {
  height: 24px;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-header, .ag-theme-balham .ag-ltr .ag-filter-toolpanel-search {
  padding-left: 4px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-header, .ag-theme-balham .ag-rtl .ag-filter-toolpanel-search {
  padding-right: 4px;
}

.ag-theme-balham .ag-keyboard-focus .ag-filter-toolpanel-header:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-filter-toolpanel-header:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-filter-toolpanel-group.ag-has-filter > .ag-group-title-bar .ag-group-title::after {
  font-family: "agGridBalham";
  font-size: 16px;
  line-height: 16px;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  content: "\f114";
  position: absolute;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group.ag-has-filter > .ag-group-title-bar .ag-group-title::after {
  padding-left: 4px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group.ag-has-filter > .ag-group-title-bar .ag-group-title::after {
  padding-right: 4px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-0-header {
  height: 32px;
}
.ag-theme-balham .ag-filter-toolpanel-group-item {
  margin-top: 2px;
  margin-bottom: 2px;
}
.ag-theme-balham .ag-filter-toolpanel-search {
  height: 32px;
}
.ag-theme-balham .ag-filter-toolpanel-search-input {
  -webkit-box-flex: 1;
          flex-grow: 1;
  height: 16px;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-search-input {
  margin-right: 4px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-search-input {
  margin-left: 4px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-0 {
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-expand, .ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-title-bar-icon {
  margin-right: 4px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-expand, .ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-title-bar-icon {
  margin-left: 4px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-1 .ag-filter-toolpanel-group-level-1-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-1 .ag-filter-toolpanel-group-level-2-header {
  padding-left: 20px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-1 .ag-filter-toolpanel-group-level-2-header {
  padding-right: 20px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-2 .ag-filter-toolpanel-group-level-2-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-2 .ag-filter-toolpanel-group-level-3-header {
  padding-left: 36px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-2 .ag-filter-toolpanel-group-level-3-header {
  padding-right: 36px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-3 .ag-filter-toolpanel-group-level-3-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-3 .ag-filter-toolpanel-group-level-4-header {
  padding-left: 52px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-3 .ag-filter-toolpanel-group-level-4-header {
  padding-right: 52px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-4 .ag-filter-toolpanel-group-level-4-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-4 .ag-filter-toolpanel-group-level-5-header {
  padding-left: 68px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-4 .ag-filter-toolpanel-group-level-5-header {
  padding-right: 68px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-5 .ag-filter-toolpanel-group-level-5-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-5 .ag-filter-toolpanel-group-level-6-header {
  padding-left: 84px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-5 .ag-filter-toolpanel-group-level-6-header {
  padding-right: 84px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-6 .ag-filter-toolpanel-group-level-6-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-6 .ag-filter-toolpanel-group-level-7-header {
  padding-left: 100px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-6 .ag-filter-toolpanel-group-level-7-header {
  padding-right: 100px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-7 .ag-filter-toolpanel-group-level-7-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-7 .ag-filter-toolpanel-group-level-8-header {
  padding-left: 116px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-7 .ag-filter-toolpanel-group-level-8-header {
  padding-right: 116px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-8 .ag-filter-toolpanel-group-level-8-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-8 .ag-filter-toolpanel-group-level-9-header {
  padding-left: 132px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-8 .ag-filter-toolpanel-group-level-9-header {
  padding-right: 132px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-9 .ag-filter-toolpanel-group-level-9-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-9 .ag-filter-toolpanel-group-level-10-header {
  padding-left: 148px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-9 .ag-filter-toolpanel-group-level-10-header {
  padding-right: 148px;
}

.ag-theme-balham .ag-filter-toolpanel-group-level-10 .ag-filter-toolpanel-group-level-10-header.ag-filter-toolpanel-group-title-bar {
  background-color: transparent;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-group-level-10 .ag-filter-toolpanel-group-level-11-header {
  padding-left: 164px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-group-level-10 .ag-filter-toolpanel-group-level-11-header {
  padding-right: 164px;
}

.ag-theme-balham .ag-filter-toolpanel-instance-header.ag-filter-toolpanel-group-level-1-header {
  padding-left: 4px;
}
.ag-theme-balham .ag-filter-toolpanel-instance-filter {
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
  margin-top: 4px;
}
.ag-theme-balham .ag-ltr .ag-filter-toolpanel-instance-header-icon {
  margin-left: 4px;
}

.ag-theme-balham .ag-rtl .ag-filter-toolpanel-instance-header-icon {
  margin-right: 4px;
}

.ag-theme-balham .ag-pivot-mode-panel {
  min-height: 32px;
  height: 32px;
  display: -webkit-box;
  display: flex;
}
.ag-theme-balham .ag-pivot-mode-select {
  display: -webkit-box;
  display: flex;
  -webkit-box-align: center;
          align-items: center;
}
.ag-theme-balham .ag-ltr .ag-pivot-mode-select {
  margin-left: 6px;
}

.ag-theme-balham .ag-rtl .ag-pivot-mode-select {
  margin-right: 6px;
}

.ag-theme-balham .ag-keyboard-focus .ag-column-select-header:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-column-select-header:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-column-select-header {
  height: 32px;
  -webkit-box-align: center;
          align-items: center;
  padding: 0 6px;
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
}
.ag-theme-balham .ag-column-panel-column-select {
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
}
.ag-theme-balham .ag-column-group-icons,
.ag-theme-balham .ag-column-select-header-icon {
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-column-select-list .ag-list-item-hovered::after {
  content: "";
  position: absolute;
  left: 0;
  right: 0;
  height: 1px;
  background-color: #0091ea;
  background-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-column-select-list .ag-item-highlight-top::after {
  top: 0;
}
.ag-theme-balham .ag-column-select-list .ag-item-highlight-bottom::after {
  bottom: 0;
}
.ag-theme-balham .ag-header {
  background-color: #f5f7f7;
  background-color: var(--ag-header-background-color, #f5f7f7);
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-header-row {
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-header-foreground-color, var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54)));
  height: 32px;
}
.ag-theme-balham .ag-pinned-right-header {
  border-left: solid 1px;
  border-left-color: #bdc3c7;
  border-left-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-pinned-left-header {
  border-right: solid 1px;
  border-right-color: #bdc3c7;
  border-right-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-ltr .ag-header-cell:not(.ag-right-aligned-header) .ag-header-label-icon {
  margin-left: 4px;
}

.ag-theme-balham .ag-rtl .ag-header-cell:not(.ag-right-aligned-header) .ag-header-label-icon {
  margin-right: 4px;
}

.ag-theme-balham .ag-ltr .ag-header-cell.ag-right-aligned-header .ag-header-label-icon {
  margin-right: 4px;
}

.ag-theme-balham .ag-rtl .ag-header-cell.ag-right-aligned-header .ag-header-label-icon {
  margin-left: 4px;
}

.ag-theme-balham .ag-header-cell,
.ag-theme-balham .ag-header-group-cell {
  padding-left: 12px;
  padding-right: 12px;
}
.ag-theme-balham .ag-header-cell.ag-header-cell-moving,
.ag-theme-balham .ag-header-group-cell.ag-header-cell-moving {
  background-color: white;
  background-color: var(--ag-header-cell-moving-background-color, var(--ag-background-color, white));
}
.ag-theme-balham .ag-keyboard-focus .ag-header-cell:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-header-cell:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-keyboard-focus .ag-header-group-cell:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-header-group-cell:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 4px;
  left: 4px;
  display: block;
  width: calc(100% - 8px);
  height: calc(100% - 8px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-header-icon {
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-header-expand-icon {
  cursor: pointer;
}
.ag-theme-balham .ag-ltr .ag-header-expand-icon {
  padding-left: 4px;
}

.ag-theme-balham .ag-rtl .ag-header-expand-icon {
  padding-right: 4px;
}

.ag-theme-balham .ag-header-row:not(:first-child) .ag-header-cell,
.ag-theme-balham .ag-header-row:not(:first-child) .ag-header-group-cell.ag-header-group-cell-with-group {
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-header-cell::after,
.ag-theme-balham .ag-header-group-cell::after {
  content: "";
  position: absolute;
  z-index: 1;
  display: block;
  width: 1px;
  height: 50%;
  top: calc(50% - 25%);
  background-color: rgba(189, 195, 199, 0.5);
  background-color: var(--ag-header-column-separator-color, rgba(189, 195, 199, 0.5));
}
.ag-theme-balham .ag-ltr .ag-header-cell::after, .ag-theme-balham .ag-ltr .ag-header-group-cell::after {
  right: 0;
}

.ag-theme-balham .ag-rtl .ag-header-cell::after, .ag-theme-balham .ag-rtl .ag-header-group-cell::after {
  left: 0;
}

.ag-theme-balham .ag-ltr .ag-header-select-all {
  margin-right: 12px;
}

.ag-theme-balham .ag-rtl .ag-header-select-all {
  margin-left: 12px;
}

.ag-theme-balham .ag-ltr .ag-floating-filter-button {
  margin-left: 12px;
}

.ag-theme-balham .ag-rtl .ag-floating-filter-button {
  margin-right: 12px;
}

.ag-theme-balham .ag-floating-filter-button-button {
  color: inherit;
  font-family: inherit;
  font-size: inherit;
  font-weight: inherit;
  line-height: inherit;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background: transparent;
  border: none;
  height: 16px;
  padding: 0;
  width: 16px;
}
.ag-theme-balham .ag-filter-loading {
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
  height: 100%;
  padding: 6px 6px;
  position: absolute;
  width: 100%;
  z-index: 1;
}
.ag-theme-balham .ag-paging-panel {
  border-top: 1px solid;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
  height: 32px;
}
.ag-theme-balham .ag-paging-panel > * {
  margin: 0 12px;
}
.ag-theme-balham .ag-paging-button {
  cursor: pointer;
}
.ag-theme-balham .ag-paging-button.ag-disabled {
  cursor: default;
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
}
.ag-theme-balham .ag-keyboard-focus .ag-paging-button:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-paging-button:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 0px;
  left: 0px;
  display: block;
  width: calc(100% - 0px);
  height: calc(100% - 0px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-paging-button, .ag-theme-balham .ag-paging-description {
  margin: 0 4px;
}
.ag-theme-balham .ag-status-bar {
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-border-color, #bdc3c7);
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
  padding-right: 16px;
  padding-left: 16px;
  line-height: 1.5;
}
.ag-theme-balham .ag-status-name-value-value {
  color: #000;
  color: var(--ag-foreground-color, #000);
}
.ag-theme-balham .ag-status-bar-center {
  text-align: center;
}
.ag-theme-balham .ag-status-name-value {
  margin-left: 4px;
  margin-right: 4px;
  padding-top: 8px;
  padding-bottom: 8px;
}
.ag-theme-balham .ag-column-drop-cell {
  background: #dddede;
  background: var(--ag-chip-background-color, #dddede);
  border-radius: 16px;
  height: 16px;
  padding: 0 2px;
  border: 1px solid transparent;
}
.ag-theme-balham .ag-keyboard-focus .ag-column-drop-cell:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-column-drop-cell:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 2px;
  left: 2px;
  display: block;
  width: calc(100% - 4px);
  height: calc(100% - 4px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-column-drop-cell-text {
  margin: 0 4px;
}
.ag-theme-balham .ag-column-drop-cell-button {
  min-width: 16px;
  margin: 0 2px;
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-column-drop-cell-drag-handle {
  margin-left: 8px;
}
.ag-theme-balham .ag-column-drop-cell-ghost {
  opacity: 0.5;
}
.ag-theme-balham .ag-column-drop-horizontal {
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
  height: 28px;
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-ltr .ag-column-drop-horizontal {
  padding-left: 12px;
}

.ag-theme-balham .ag-rtl .ag-column-drop-horizontal {
  padding-right: 12px;
}

.ag-theme-balham .ag-ltr .ag-column-drop-horizontal-half-width:not(:last-child) {
  border-right: solid 1px;
  border-right-color: #bdc3c7;
  border-right-color: var(--ag-border-color, #bdc3c7);
}

.ag-theme-balham .ag-rtl .ag-column-drop-horizontal-half-width:not(:last-child) {
  border-left: solid 1px;
  border-left-color: #bdc3c7;
  border-left-color: var(--ag-border-color, #bdc3c7);
}

.ag-theme-balham .ag-column-drop-horizontal-cell-separator {
  margin: 0 4px;
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-column-drop-horizontal-empty-message {
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
}
.ag-theme-balham .ag-ltr .ag-column-drop-horizontal-icon {
  margin-right: 12px;
}

.ag-theme-balham .ag-rtl .ag-column-drop-horizontal-icon {
  margin-left: 12px;
}

.ag-theme-balham .ag-column-drop-vertical-list {
  padding-bottom: 4px;
  padding-right: 4px;
  padding-left: 4px;
}
.ag-theme-balham .ag-column-drop-vertical-cell {
  margin-top: 4px;
}
.ag-theme-balham .ag-column-drop-vertical {
  min-height: 50px;
  border-bottom: solid 1px;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
}
.ag-theme-balham .ag-column-drop-vertical.ag-last-column-drop {
  border-bottom: none;
}
.ag-theme-balham .ag-column-drop-vertical-icon {
  margin-left: 4px;
  margin-right: 4px;
}
.ag-theme-balham .ag-column-drop-vertical-empty-message {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  overflow: hidden;
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
  margin-top: 4px;
}
.ag-theme-balham .ag-select-agg-func-popup {
  border: solid 1px;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  background: white;
  background: var(--ag-background-color, white);
  border-radius: 2px;
  -webkit-box-shadow: none;
          box-shadow: none;
  padding: 4px;
  background: white;
  background: var(--ag-background-color, white);
  height: 70px;
  padding: 0;
}
.ag-theme-balham .ag-select-agg-func-virtual-list-item {
  cursor: default;
  padding-left: 8px;
}
.ag-theme-balham .ag-select-agg-func-virtual-list-item:hover {
  background-color: #b7e4ff;
  background-color: var(--ag-selected-row-background-color, #b7e4ff);
}
.ag-theme-balham .ag-keyboard-focus .ag-select-agg-func-virtual-list-item:focus {
  outline: none;
}
.ag-theme-balham .ag-keyboard-focus .ag-select-agg-func-virtual-list-item:focus::after {
  content: "";
  position: absolute;
  background-color: transparent;
  pointer-events: none;
  top: 1px;
  left: 1px;
  display: block;
  width: calc(100% - 2px);
  height: calc(100% - 2px);
  border: 1px solid;
  border-color: #719ECE;
  border-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham .ag-chart-menu {
  border-radius: 2px;
  background: white;
  background: var(--ag-background-color, white);
}
.ag-theme-balham .ag-chart-menu-icon {
  opacity: 0.5;
  line-height: 24px;
  font-size: 24px;
  width: 24px;
  height: 24px;
  margin: 2px 0;
  cursor: pointer;
  border-radius: 2px;
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-chart-menu-icon:hover {
  opacity: 1;
}
.ag-theme-balham .ag-chart-mini-thumbnail {
  border: 1px solid;
  border-color: #bdc3c7;
  border-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
  border-radius: 5px;
  margin: 5px;
}
.ag-theme-balham .ag-chart-mini-thumbnail:nth-last-child(3), .ag-theme-balham .ag-chart-mini-thumbnail:nth-last-child(3) ~ .ag-chart-mini-thumbnail {
  margin-left: auto;
  margin-right: auto;
}
.ag-theme-balham .ag-ltr .ag-chart-mini-thumbnail:first-child {
  margin-left: 0;
}

.ag-theme-balham .ag-rtl .ag-chart-mini-thumbnail:first-child {
  margin-right: 0;
}

.ag-theme-balham .ag-ltr .ag-chart-mini-thumbnail:last-child {
  margin-right: 0;
}

.ag-theme-balham .ag-rtl .ag-chart-mini-thumbnail:last-child {
  margin-left: 0;
}

.ag-theme-balham .ag-chart-mini-thumbnail.ag-selected {
  border-color: #0091ea;
  border-color: var(--ag-minichart-selected-chart-color, var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea)));
}
.ag-theme-balham .ag-chart-settings-card-item {
  background: #000;
  background: var(--ag-foreground-color, #000);
  width: 8px;
  height: 8px;
  border-radius: 4px;
}
.ag-theme-balham .ag-chart-settings-card-item.ag-selected {
  background-color: #0091ea;
  background-color: var(--ag-minichart-selected-page-color, var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea)));
}
.ag-theme-balham .ag-chart-data-column-drag-handle {
  margin-left: 4px;
}
.ag-theme-balham .ag-charts-settings-group-title-bar,
.ag-theme-balham .ag-charts-data-group-title-bar,
.ag-theme-balham .ag-charts-format-top-level-group-title-bar {
  border-top: solid 1px;
  border-top-color: #bdc3c7;
  border-top-color: var(--ag-secondary-border-color, var(--ag-border-color, #bdc3c7));
}
.ag-theme-balham .ag-charts-settings-group-container {
  padding: 4px;
}
.ag-theme-balham .ag-charts-data-group-container {
  padding: 3px 6px;
}
.ag-theme-balham .ag-charts-data-group-container .ag-charts-data-group-item:not(.ag-charts-format-sub-level-group) {
  height: 24px;
}
.ag-theme-balham .ag-charts-data-group-container .ag-list-item-hovered::after {
  content: "";
  position: absolute;
  left: 0;
  right: 0;
  height: 1px;
  background-color: #0091ea;
  background-color: var(--ag-range-selection-border-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham .ag-charts-data-group-container .ag-item-highlight-top::after {
  top: 0;
}
.ag-theme-balham .ag-charts-data-group-container .ag-item-highlight-bottom::after {
  bottom: 0;
}
.ag-theme-balham .ag-charts-format-top-level-group-container {
  margin-left: 8px;
  padding: 4px;
}
.ag-theme-balham .ag-charts-format-top-level-group-item {
  margin: 4px 0;
}
.ag-theme-balham .ag-charts-format-sub-level-group-container {
  padding: 6px 6px;
  padding-bottom: 2px;
}
.ag-theme-balham .ag-charts-format-sub-level-group-container > * {
  margin-bottom: 4px;
}
.ag-theme-balham .ag-charts-group-container.ag-group-container-horizontal {
  padding: 4px;
}
.ag-theme-balham .ag-chart-data-section,
.ag-theme-balham .ag-chart-format-section {
  display: -webkit-box;
  display: flex;
  margin: 0;
}
.ag-theme-balham .ag-chart-menu-panel {
  background-color: #f5f7f7;
  background-color: var(--ag-control-panel-background-color, #f5f7f7);
}
.ag-theme-balham .ag-ltr .ag-chart-menu-panel {
  border-left: solid 1px;
  border-left-color: #bdc3c7;
  border-left-color: var(--ag-border-color, #bdc3c7);
}

.ag-theme-balham .ag-rtl .ag-chart-menu-panel {
  border-right: solid 1px;
  border-right-color: #bdc3c7;
  border-right-color: var(--ag-border-color, #bdc3c7);
}

.ag-theme-balham .ag-date-time-list-page-title {
  -webkit-box-flex: 1;
          flex-grow: 1;
  text-align: center;
}
.ag-theme-balham .ag-date-time-list-page-column-label {
  text-align: center;
}
.ag-theme-balham .ag-date-time-list-page-entry {
  text-align: center;
}
.ag-theme-balham .ag-checkbox-input-wrapper {
  font-family: "agGridBalham";
  font-size: 16px;
  line-height: 16px;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  width: 16px;
  height: 16px;
  background-color: white;
  background-color: var(--ag-checkbox-background-color, var(--ag-background-color, white));
  border-radius: 3px;
  display: inline-block;
  vertical-align: middle;
  -webkit-box-flex: 0;
          flex: none;
}
.ag-theme-balham .ag-checkbox-input-wrapper input, .ag-theme-balham .ag-checkbox-input-wrapper input {
  -webkit-appearance: none;
  opacity: 0;
  width: 100%;
  height: 100%;
}
.ag-theme-balham .ag-checkbox-input-wrapper:focus-within, .ag-theme-balham .ag-checkbox-input-wrapper:active {
  outline: none;
  -webkit-box-shadow: 0 0 2px 1px #719ECE;
          box-shadow: 0 0 2px 1px #719ECE;
}
.ag-theme-balham .ag-checkbox-input-wrapper.ag-disabled {
  opacity: 0.5;
}
.ag-theme-balham .ag-checkbox-input-wrapper::after {
  content: "\f108";
  color: #7f8c8d;
  color: var(--ag-checkbox-unchecked-color, #7f8c8d);
  position: absolute;
  top: 0;
  left: 0;
  pointer-events: none;
}
.ag-theme-balham .ag-checkbox-input-wrapper.ag-checked::after {
  content: "\f106";
  color: #0091ea;
  color: var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea));
  position: absolute;
  top: 0;
  left: 0;
  pointer-events: none;
}
.ag-theme-balham .ag-checkbox-input-wrapper.ag-indeterminate::after {
  content: "\f107";
  color: #7f8c8d;
  color: var(--ag-checkbox-indeterminate-color, var(--ag-checkbox-unchecked-color, #7f8c8d));
  position: absolute;
  top: 0;
  left: 0;
  pointer-events: none;
}
.ag-theme-balham .ag-toggle-button-input-wrapper {
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  width: 32px;
  height: 16px;
  background-color: #7f8c8d;
  background-color: var(--ag-toggle-button-off-background-color, var(--ag-checkbox-unchecked-color, #7f8c8d));
  border-radius: 8px;
  position: relative;
  -webkit-box-flex: 0;
          flex: none;
  border: 1px solid;
  border-color: #7f8c8d;
  border-color: var(--ag-toggle-button-off-border-color, var(--ag-checkbox-unchecked-color, #7f8c8d));
}
.ag-theme-balham .ag-toggle-button-input-wrapper input {
  opacity: 0;
  height: 100%;
  width: 100%;
}
.ag-theme-balham .ag-toggle-button-input-wrapper:focus-within {
  outline: none;
  -webkit-box-shadow: 0 0 2px 1px #719ECE;
          box-shadow: 0 0 2px 1px #719ECE;
}
.ag-theme-balham .ag-toggle-button-input-wrapper.ag-disabled {
  opacity: 0.5;
}
.ag-theme-balham .ag-toggle-button-input-wrapper.ag-checked {
  background-color: #0091ea;
  background-color: var(--ag-toggle-button-on-background-color, var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea)));
  border-color: #0091ea;
  border-color: var(--ag-toggle-button-on-border-color, var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea)));
}
.ag-theme-balham .ag-toggle-button-input-wrapper::before {
  content: " ";
  position: absolute;
  top: -1px;
  left: -1px;
  display: block;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  height: 16px;
  width: 16px;
  background-color: white;
  background-color: var(--ag-toggle-button-switch-background-color, var(--ag-background-color, white));
  border-radius: 8px;
  -webkit-transition: left 100ms;
  transition: left 100ms;
  border: 1px solid;
  border-color: #7f8c8d;
  border-color: var(--ag-toggle-button-switch-border-color, var(--ag-toggle-button-off-border-color, var(--ag-checkbox-unchecked-color, #7f8c8d)));
}
.ag-theme-balham .ag-toggle-button-input-wrapper.ag-checked::before {
  left: calc(100% - 16px );
  border-color: #0091ea;
  border-color: var(--ag-toggle-button-on-border-color, var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea)));
}
.ag-theme-balham .ag-radio-button-input-wrapper {
  font-family: "agGridBalham";
  font-size: 16px;
  line-height: 16px;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  width: 16px;
  height: 16px;
  background-color: white;
  background-color: var(--ag-checkbox-background-color, var(--ag-background-color, white));
  border-radius: 3px;
  display: inline-block;
  vertical-align: middle;
  -webkit-box-flex: 0;
          flex: none;
  border-radius: 16px;
}
.ag-theme-balham .ag-radio-button-input-wrapper input, .ag-theme-balham .ag-radio-button-input-wrapper input {
  -webkit-appearance: none;
  opacity: 0;
  width: 100%;
  height: 100%;
}
.ag-theme-balham .ag-radio-button-input-wrapper:focus-within, .ag-theme-balham .ag-radio-button-input-wrapper:active {
  outline: none;
  -webkit-box-shadow: 0 0 2px 1px #719ECE;
          box-shadow: 0 0 2px 1px #719ECE;
}
.ag-theme-balham .ag-radio-button-input-wrapper.ag-disabled {
  opacity: 0.5;
}
.ag-theme-balham .ag-radio-button-input-wrapper::after {
  content: "\f126";
  color: #7f8c8d;
  color: var(--ag-checkbox-unchecked-color, #7f8c8d);
  position: absolute;
  top: 0;
  left: 0;
  pointer-events: none;
}
.ag-theme-balham .ag-radio-button-input-wrapper.ag-checked::after {
  content: "\f127";
  color: #0091ea;
  color: var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea));
  position: absolute;
  top: 0;
  left: 0;
  pointer-events: none;
}
.ag-theme-balham input[class^=ag-][type=range] {
  -webkit-appearance: none;
  width: 100%;
  height: 100%;
  background: none;
  overflow: visible;
}
.ag-theme-balham input[class^=ag-][type=range]::-webkit-slider-runnable-track {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 3px;
  background-color: #bdc3c7;
  background-color: var(--ag-border-color, #bdc3c7);
  border-radius: 2px;
  border-radius: 3px;
}
.ag-theme-balham input[class^=ag-][type=range]::-moz-range-track {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 3px;
  background-color: #bdc3c7;
  background-color: var(--ag-border-color, #bdc3c7);
  border-radius: 2px;
  border-radius: 3px;
}
.ag-theme-balham input[class^=ag-][type=range]::-ms-track {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 3px;
  background-color: #bdc3c7;
  background-color: var(--ag-border-color, #bdc3c7);
  border-radius: 2px;
  border-radius: 3px;
  color: transparent;
  width: calc(100% - 2px);
}
.ag-theme-balham input[class^=ag-][type=range]::-webkit-slider-thumb {
  margin: 0;
  padding: 0;
  -webkit-appearance: none;
  width: 16px;
  height: 16px;
  background-color: white;
  background-color: var(--ag-background-color, white);
  border: 1px solid;
  border-color: #7f8c8d;
  border-color: var(--ag-checkbox-unchecked-color, #7f8c8d);
  border-radius: 16px;
  -webkit-transform: translateY(-6.5px);
          transform: translateY(-6.5px);
}
.ag-theme-balham input[class^=ag-][type=range]::-ms-thumb {
  margin: 0;
  padding: 0;
  -webkit-appearance: none;
  width: 16px;
  height: 16px;
  background-color: white;
  background-color: var(--ag-background-color, white);
  border: 1px solid;
  border-color: #7f8c8d;
  border-color: var(--ag-checkbox-unchecked-color, #7f8c8d);
  border-radius: 16px;
}
.ag-theme-balham input[class^=ag-][type=range]::-moz-ag-range-thumb {
  margin: 0;
  padding: 0;
  -webkit-appearance: none;
  width: 16px;
  height: 16px;
  background-color: white;
  background-color: var(--ag-background-color, white);
  border: 1px solid;
  border-color: #7f8c8d;
  border-color: var(--ag-checkbox-unchecked-color, #7f8c8d);
  border-radius: 16px;
}
.ag-theme-balham input[class^=ag-][type=range]:focus {
  outline: none;
}
.ag-theme-balham input[class^=ag-][type=range]:focus::-webkit-slider-thumb {
  -webkit-box-shadow: 0 0 2px 1px #719ECE;
          box-shadow: 0 0 2px 1px #719ECE;
  border-color: #0091ea;
  border-color: var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham input[class^=ag-][type=range]:focus::-ms-thumb {
  box-shadow: 0 0 2px 1px #719ECE;
  border-color: #0091ea;
  border-color: var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham input[class^=ag-][type=range]:focus::-moz-ag-range-thumb {
  box-shadow: 0 0 2px 1px #719ECE;
  border-color: #0091ea;
  border-color: var(--ag-checkbox-checked-color, var(--ag-balham-active-color, #0091ea));
}
.ag-theme-balham input[class^=ag-][type=range]:active::-webkit-slider-runnable-track {
  background-color: #719ECE;
  background-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham input[class^=ag-][type=range]:active::-moz-ag-range-track {
  background-color: #719ECE;
  background-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham input[class^=ag-][type=range]:active::-ms-track {
  background-color: #719ECE;
  background-color: var(--ag-input-focus-border-color, #719ECE);
}
.ag-theme-balham input[class^=ag-][type=range]:disabled {
  opacity: 0.5;
}
.ag-theme-balham .ag-filter-toolpanel-header,
.ag-theme-balham .ag-filter-toolpanel-search,
.ag-theme-balham .ag-status-bar,
.ag-theme-balham .ag-header-row,
.ag-theme-balham .ag-multi-filter-group-title-bar {
  font-weight: 600;
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-header-foreground-color, var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54)));
}
.ag-theme-balham .ag-ltr input[class^=ag-]:not([type]),
.ag-theme-balham .ag-ltr input[class^=ag-][type=text],
.ag-theme-balham .ag-ltr input[class^=ag-][type=number],
.ag-theme-balham .ag-ltr input[class^=ag-][type=tel],
.ag-theme-balham .ag-ltr input[class^=ag-][type=date],
.ag-theme-balham .ag-ltr input[class^=ag-][type=datetime-local],
.ag-theme-balham .ag-ltr textarea[class^=ag-] {
  padding-left: 4px;
}

.ag-theme-balham .ag-rtl input[class^=ag-]:not([type]),
.ag-theme-balham .ag-rtl input[class^=ag-][type=text],
.ag-theme-balham .ag-rtl input[class^=ag-][type=number],
.ag-theme-balham .ag-rtl input[class^=ag-][type=tel],
.ag-theme-balham .ag-rtl input[class^=ag-][type=date],
.ag-theme-balham .ag-rtl input[class^=ag-][type=datetime-local],
.ag-theme-balham .ag-rtl textarea[class^=ag-] {
  padding-right: 4px;
}

.ag-theme-balham .ag-column-drop-vertical-empty-message, .ag-theme-balham .ag-status-bar {
  font-weight: 600;
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
}
.ag-theme-balham .ag-dnd-ghost {
  font-weight: 600;
}
.ag-theme-balham .ag-tab {
  border: 1px solid transparent;
  padding: 4px 8px;
  margin: 4px;
  margin-bottom: -1px;
}
.ag-theme-balham .ag-tab-selected {
  background-color: white;
  background-color: var(--ag-background-color, white);
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  border-bottom-color: transparent;
}
.ag-theme-balham .ag-tabs-header {
  border-bottom: 1px solid;
  border-bottom-color: #bdc3c7;
  border-bottom-color: var(--ag-border-color, #bdc3c7);
}
.ag-theme-balham .ag-column-drop-cell {
  height: 24px;
}
.ag-theme-balham .ag-column-drop-vertical-title {
  color: #000;
  color: var(--ag-foreground-color, #000);
}
.ag-theme-balham .ag-column-drop-vertical-cell {
  margin-left: 8px;
  margin-right: 8px;
}
.ag-theme-balham .ag-column-drop-vertical-cell-text {
  margin-left: 8px;
}
.ag-theme-balham .ag-column-drop-vertical-icon {
  color: rgba(0, 0, 0, 0.54);
  color: var(--ag-secondary-foreground-color, rgba(0, 0, 0, 0.54));
}
.ag-theme-balham .ag-ltr .ag-column-drop-vertical-empty-message {
  padding-left: 24px;
  padding-right: 4px;
}

.ag-theme-balham .ag-rtl .ag-column-drop-vertical-empty-message {
  padding-right: 24px;
  padding-left: 4px;
}

.ag-theme-balham .ag-column-drop-horizontal {
  height: 32px;
}
.ag-theme-balham .ag-column-drop-empty {
  color: rgba(0, 0, 0, 0.38);
  color: var(--ag-disabled-foreground-color, rgba(0, 0, 0, 0.38));
}
.ag-theme-balham .ag-column-drop-horizontal-cell-text {
  margin-left: 8px;
}
.ag-theme-balham .ag-column-drop-vertical {
  padding-top: 8px;
}
.ag-theme-balham .ag-menu-header {
  background-color: #f5f7f7;
  background-color: var(--ag-header-background-color, #f5f7f7);
}
.ag-theme-balham .ag-overlay-loading-center {
  background-color: white;
  background-color: var(--ag-background-color, white);
  border: 1px solid;
  border-color: #bdc3c7;
  border-color: var(--ag-border-color, #bdc3c7);
  color: #000;
  color: var(--ag-foreground-color, #000);
  padding: 16px;
}
.ag-theme-balham .ag-tooltip {
  border: none;
  background-color: #cbd0d3;
}
.ag-theme-balham .ag-panel-title-bar-button-icon {
  font-size: 20px;
}
.ag-theme-balham .ag-chart-data-section,
.ag-theme-balham .ag-chart-format-section {
  padding-bottom: 2px;
}
.ag-theme-balham .ag-group-toolbar {
  background-color: rgba(226, 233, 235, 0.5);
  background-color: var(--ag-subheader-toolbar-background-color, rgba(226, 233, 235, 0.5));
}
.ag-theme-balham .ag-chart-tab {
  padding-top: 2px;
}
.ag-theme-balham .ag-charts-format-sub-level-group-item {
  margin-bottom: 6px;
}
